@@ -1,14 +1,15 @@
 ;;; Directory Local Variables
-;;; See Info node `(emacs) Directory Variables' for more information.
+;;; For more information see (info "(emacs) Directory Variables")
 
 ((python-mode
+  (python-indent-offset . 2)
   (py-continuation-offset . 4)
   (py-smart-indentation)
   (py-indent-offset . 2)
-  (flycheck-checker . python-pylint)
   (flycheck-pylintrc . "pylintrc")))
 
 
 
 
 
+
