@@ -13,6 +13,7 @@ import logging.config
 import os
 from functools import partial
 from itertools import chain, count
+from pathlib import Path
 
 import jinja2
 import sqlalchemy as sa
@@ -28,9 +29,8 @@ from flask_assets import Bundle
 from flask_babel import get_locale as babel_get_locale
 from flask_migrate import Migrate
 from flask_script import Manager as ScriptManager
-from future.utils import string_types
-from pathlib import Path
 from pkg_resources import resource_filename
+from six import string_types, text_type
 from sqlalchemy.orm.attributes import NEVER_SET, NO_VALUE
 from werkzeug.datastructures import ImmutableDict
 from werkzeug.utils import import_string
@@ -41,11 +41,10 @@ from abilian.core import extensions, redis, signals
 from abilian.core.celery import FlaskCelery
 from abilian.plugin.loader import AppLoader
 from abilian.services import converter as conversion_service
-from abilian.services import (activity_service, antivirus, audit_service,
-                              auth_service, index_service, preferences_service,
-                              repository_service, security_service,
-                              session_repository_service, settings_service,
-                              vocabularies_service)
+from abilian.services import (
+    activity_service, antivirus, audit_service, auth_service, index_service,
+    preferences_service, repository_service, security_service,
+    session_repository_service, settings_service, vocabularies_service)
 from abilian.services.security import Anonymous
 from abilian.web import csrf
 from abilian.web.action import Endpoint, actions
@@ -166,12 +165,13 @@ class Application(Flask, ServiceManager, PluginManager):
     private_site = ConfigAttribute('PRIVATE_SITE')
 
     #: instance of :class:`.web.views.registry.Registry`.
+    # type: web.views.registry.Registry
     default_view = None
 
     #: json serializable dict to land in Javascript under Abilian.api
     js_api = None
 
-    #: :class:`flask.ext.script.Manager` instance for shell commands of this app.
+    #: :class:`flask_script.Manager` instance for shell commands of this app.
     #: defaults to `.commands.manager`, relative to app name.
     script_manager = '.commands.manager'
 
@@ -184,8 +184,8 @@ class Application(Flask, ServiceManager, PluginManager):
 
         # used by make_config to determine if we try to load config from instance /
         # environment variable /...
-        self._ABILIAN_INIT_TESTING_FLAG = (getattr(config, 'TESTING', False) if
-                                           config else False)
+        self._ABILIAN_INIT_TESTING_FLAG = (getattr(config, 'TESTING', False)
+                                           if config else False)
         Flask.__init__(self, name, *args, **kwargs)
         del self._ABILIAN_INIT_TESTING_FLAG
 
@@ -253,8 +253,8 @@ class Application(Flask, ServiceManager, PluginManager):
         self.register_jinja_loaders(jinja2.PackageLoader('abilian.web',
                                                          'templates'))
 
-        js_filters = (('closure_js',) if self.config.get('PRODUCTION', False)
-                      else None)
+        js_filters = (('closure_js',)
+                      if self.config.get('PRODUCTION', False) else None)
 
         self._assets_bundles = {
             'css': {'options': dict(filters=('less', 'cssmin'),
@@ -321,7 +321,7 @@ class Application(Flask, ServiceManager, PluginManager):
         if manager is None or isinstance(manager, ScriptManager):
             return
 
-        if isinstance(manager, (bytes, unicode)):
+        if isinstance(manager, string_types):
             manager = str(manager)
             if manager.startswith('.'):
                 manager = self.import_name + manager
@@ -384,8 +384,7 @@ class Application(Flask, ServiceManager, PluginManager):
 
         if not path.exists():
             if create:
-                logger.info('Create instance folder: %s',
-                            unicode(path).encode('utf-8'))
+                logger.info('Create instance folder: %s', path)
                 path.mkdir(0o775, parents=True)
             else:
                 err = 'Instance folder does not exists'
@@ -464,7 +463,7 @@ class Application(Flask, ServiceManager, PluginManager):
         if (not self.testing and self.config.get('DEBUG_TB_ENABLED') and
                 'debugtoolbar' not in self.blueprints):
             try:
-                from flask_debugtoolbar import DebugToolbarExtension, DebugToolbar
+                from flask_debugtoolbar import DebugToolbarExtension
             except ImportError:
                 logger.warning('DEBUG_TB_ENABLED is on but flask_debugtoolbar '
                                'is not installed.')
@@ -966,7 +965,7 @@ class Application(Flask, ServiceManager, PluginManager):
            app.errorhandler(code)(handler)
         """
         # 5xx code: error on server side
-        if (code / 100) == 5:
+        if (code // 100) == 5:
             # ensure rollback if needed, else error page may
             # have an error, too, resulting in raw 500 page :-(
             db.session.rollback()
