@@ -5,12 +5,14 @@ from __future__ import (absolute_import, division, print_function,
 import logging
 import os
 import runpy
-import urllib
 from pprint import pformat
 
+from six.moves import input
+from six.moves import urllib
 import sqlalchemy as sa
 from flask import current_app
 from flask_script import Manager, prompt_pass
+from six import text_type
 
 from abilian.core.extensions import db
 from abilian.core.logging import patch_logger
@@ -27,7 +29,7 @@ __all__ = ['manager', 'logger']
 logging.basicConfig()
 logger = logging.getLogger('')
 
-# PATCH flask.ext.script.Manager.run to force creation of app before run() is
+# PATCH flask_script.Manager.run to force creation of app before run() is
 # called. In default implementation, the arg parser is created before the Flask
 # application. So we can't use app.script_manager to add commands from
 # plugins. If app is created before the arg parser, plugin commands are properly
@@ -47,7 +49,7 @@ def _manager_run(self, *args, **kwargs):
 patch_logger.info(Manager.run)
 Manager.run = _manager_run
 
-#: ``flask.ext.script.Manager`` instance for abilian commands
+#: ``flask_script.Manager`` instance for abilian commands
 manager = Manager(usage='Abilian base commands')
 
 
@@ -141,7 +143,7 @@ def initdb():
 def dropdb():
     """Drop the application DB.
     """
-    confirm = raw_input("Are you sure you want to drop the database? (Y/N) ")
+    confirm = input("Are you sure you want to drop the database? (Y/N) ")
     print("Dropping DB using engine: {}".format(db))
     if confirm.lower() == 'y':
         # with current_app.app_context():
@@ -155,8 +157,8 @@ def routes():
     output = []
     for rule in current_app.url_map.iter_rules():
         methods = ','.join(rule.methods)
-        path = urllib.unquote(rule.rule)
-        # line = urllib.unquote()
+        path = urllib.parse.unquote(rule.rule)
+        # line = urllib.parse.unquote()
         output.append((rule.endpoint, methods, path))
 
     for endpoint, methods, path in sorted(output):
@@ -193,7 +195,7 @@ firstname_opt = manager.option('-f',
 def createuser(email, password, role=None, name=None, first_name=None):
     """Create new user.
     """
-    email = unicode(email)
+    email = text_type(email)
     if User.query.filter(User.email == email).count() > 0:
         print("A user with email '{}' already exists, aborting.".format(email))
         return
