@@ -13,6 +13,7 @@ from inspect import isclass
 
 import sqlalchemy as sa
 from flask import current_app
+from six import text_type, with_metaclass
 from sqlalchemy import event
 from sqlalchemy.ext.declarative import declared_attr
 from sqlalchemy.orm import Session, mapper
@@ -147,8 +148,9 @@ class EntityQuery(db.Model.query_class):
     def with_permission(self, permission, user=None):
         security = current_app.services['security']
         model = self._entity_zero().entity_zero.entity
-        expr = security.query_entity_with_permission(
-            permission, user, Model=model)
+        expr = security.query_entity_with_permission(permission,
+                                                     user,
+                                                     Model=model)
         return self.filter(expr)
 
 
@@ -195,8 +197,8 @@ class EntityMeta(BaseMeta):
                     for permission, roles in default_permissions)
                 d['__default_permissions__'] = default_permissions
 
-            d['SLUG_SEPARATOR'] = unicode(d.get('SLUG_SEPARATOR',
-                                                Entity.SLUG_SEPARATOR))
+            d['SLUG_SEPARATOR'] = text_type(d.get('SLUG_SEPARATOR',
+                                                  Entity.SLUG_SEPARATOR))
 
         cls = BaseMeta.__new__(mcs, classname, bases, d)
 
@@ -213,9 +215,8 @@ class EntityMeta(BaseMeta):
         BaseMeta.__init__(cls, classname, bases, d)
 
 
-class Entity(Indexable, BaseMixin, db.Model):
-    """
-    Base class for Abilian entities.
+class Entity(with_metaclass(EntityMeta, Indexable, BaseMixin, db.Model)):
+    """Base class for Abilian entities.
 
     From Sqlalchemy POV, Entities use `Joined-Table inheritance
     <http://docs.sqlalchemy.org/en/rel_0_8/orm/inheritance.html#joined-table-inheritance>`_,
@@ -238,7 +239,7 @@ class Entity(Indexable, BaseMixin, db.Model):
               args['order_by'] = cls.created_at # for example
               return args
     """
-    __metaclass__ = EntityMeta
+    # __metaclass__ = EntityMeta
     __indexable__ = False
     __indexation_args__ = {}
     __indexation_args__.update(Indexable.__indexation_args__)
@@ -324,7 +325,7 @@ class Entity(Indexable, BaseMixin, db.Model):
 
     @property
     def object_type(self):
-        return unicode(self.entity_type)
+        return text_type(self.entity_type)
 
     @classmethod
     def _object_type(cls):
@@ -360,13 +361,13 @@ class Entity(Indexable, BaseMixin, db.Model):
             session = sa.orm.object_session(self)
             if not session:
                 return None
-            q = session.query(Entity.slug) \
+            query = session.query(Entity.slug) \
                 .filter(Entity._entity_type == self.object_type)
             if self.id is not None:
-                q = q.filter(Entity.id != self.id)
+                query = query.filter(Entity.id != self.id)
             slug_re = re.compile(re.escape(slug) + r'-?(-\d+)?')
             results = [int(m.group(1) or 0)  # 0: for the unnumbered slug
-                       for m in (slug_re.match(s.slug) for s in q.all()
+                       for m in (slug_re.match(s.slug) for s in query.all()
                                  if s.slug) if m]
 
             max_id = max(-1, -1, *results) + 1
@@ -376,8 +377,8 @@ class Entity(Indexable, BaseMixin, db.Model):
 
     @property
     def _indexable_roles_and_users(self):
-        """Return a string made for indexing roles having :any:`READ` permission on
-        this object.
+        """Return a string made for indexing roles having :any:`READ`
+        permission on this object.
         """
         from abilian.services.indexing import indexable_role
         from abilian.services.security import READ, Admin, Anonymous, Creator, Owner
@@ -392,7 +393,8 @@ class Entity(Indexable, BaseMixin, db.Model):
         for r in allowed_roles:
             result.append(indexable_role(r))
 
-        for role, attr in ((Creator, 'creator'), (Owner, 'owner'),):
+        for role, attr in ((Creator, 'creator'),
+                           (Owner, 'owner'),):
             if role in allowed_roles:
                 user = getattr(self, attr)
                 if user:
@@ -416,7 +418,8 @@ class Entity(Indexable, BaseMixin, db.Model):
 
     @property
     def _indexable_tags(self):
-        """Index tag ids for tags defined in this Entity's default tags namespace.
+        """Index tag ids for tags defined in this Entity's default tags
+        namespace.
         """
         tags = current_app.extensions['tags']
 
@@ -428,11 +431,11 @@ class Entity(Indexable, BaseMixin, db.Model):
 
     @property
     def _indexable_tag_ids(self):
-        return u' '.join(unicode(t.id) for t in self._indexable_tags)
+        return u' '.join(text_type(t.id) for t in self._indexable_tags)
 
     @property
     def _indexable_tag_text(self):
-        return u' '.join(unicode(t.label) for t in self._indexable_tags)
+        return u' '.join(text_type(t.label) for t in self._indexable_tags)
 
 
 # TODO: make this unecessary
