@@ -10,6 +10,9 @@ import uuid
 
 import sqlalchemy as sa
 from flask_sqlalchemy import BaseQuery
+from six import text_type
+from sqlalchemy.event import listens_for
+from sqlalchemy.orm.exc import NoResultFound
 from sqlalchemy.schema import Column
 from sqlalchemy.types import Integer
 
@@ -22,14 +25,14 @@ class BlobQuery(BaseQuery):
     """
 
     def by_uuid(self, uuid):
-        """
-    Like `.get()` but by uuid
+        """Like `.get()` but by uuid.
 
-    :param uuid: a `string` or an `uuid`.
-    """
+        :param uuid: a `string` or an `uuid`.
+        """
+        # type: (str) -> Blob
         try:
             return self.filter_by(uuid=uuid).one()
-        except sa.orm.exc.NoResultFound:
+        except NoResultFound:
             return None
 
 
@@ -88,7 +91,7 @@ class Blob(Model):
         """
         from abilian.services.repository import session_repository as repository
         repository.set(self, self.uuid, value)
-        self.meta['md5'] = unicode(hashlib.md5(self.value).hexdigest())
+        self.meta['md5'] = text_type(hashlib.md5(self.value).hexdigest())
 
         if hasattr(value, 'filename'):
             filename = getattr(value, 'filename')
@@ -112,7 +115,7 @@ class Blob(Model):
         """
         md5 = self.meta.get('md5')
         if md5 is None:
-            md5 = unicode(hashlib.md5(self.value).hexdigest())
+            md5 = text_type(hashlib.md5(self.value).hexdigest())
 
         return md5
 
@@ -122,7 +125,7 @@ class Blob(Model):
         return self.file is not None and self.file.exists()
 
 
-@sa.event.listens_for(sa.orm.Session, 'after_flush')
+@listens_for(sa.orm.Session, 'after_flush')
 def _blob_propagate_delete_content(session, flush_context):
     deleted = (obj for obj in session.deleted if isinstance(obj, Blob))
     for blob in deleted:
