@@ -10,7 +10,8 @@ Cf. http://flask.pocoo.org/docs/signals/ for detailed documentation.
 The main signal is currently :obj:`activity`.
 """
 
-from __future__ import absolute_import
+from __future__ import (absolute_import, division, print_function,
+                        unicode_literals)
 
 from blinker.base import Namespace
 
@@ -30,17 +31,3 @@ activity = signals.signal("activity")
 #: This signal is sent when user object has been loaded. g.user and current_user
 #: are available.
 user_loaded = signals.signal('user_loaded')
-
-#: Currently not used and subject to change.
-entity_created = signals.signal("entity:created")
-
-#: Currently not used and subject to change.
-entity_updated = signals.signal("entity:updated")
-
-#: Currently not used and subject to change.
-entity_deleted = signals.signal("entity:deleted")
-
-# user_created = signals.signal("user:created")
-# user_deleted = signals.signal("user:deleted")
-
-# More signals ?
