@@ -4,6 +4,7 @@
 from __future__ import (absolute_import, division, print_function,
                         unicode_literals)
 
+from six import text_type, with_metaclass
 from sqlalchemy.types import String, TypeDecorator
 
 
@@ -26,17 +27,17 @@ class ValueSingletonMeta(type):
         return cls.__instances__[value]
 
 
-class UniqueName(object):
+class UniqueName(with_metaclass(ValueSingletonMeta, object)):
     """Base class to create singletons from strings.
 
     A subclass of :class:`UniqueName` defines a namespace.
     """
-    __metaclass__ = ValueSingletonMeta
+    # __metaclass__ = ValueSingletonMeta
     __slots__ = ('_hash', '__name')
     attr = 'name'
 
     def __init__(self, name):
-        self.__name = unicode(name).strip().lower()
+        self.__name = text_type(name).strip().lower()
         self._hash = hash(self.__name)
 
     @property
@@ -55,7 +56,7 @@ class UniqueName(object):
     def __eq__(self, other):
         if isinstance(other, self.__class__):
             return self._hash == other._hash
-        return self.__name == unicode(other)
+        return self.__name == text_type(other)
 
     def __hash__(self):
         return self._hash
