@@ -8,26 +8,22 @@ import json
 import logging
 import sys
 import uuid
-from distutils.version import StrictVersion
-from functools import partial
 
 import babel
 import flask_sqlalchemy as flask_sa
-import pkg_resources
 import pytz
 import sqlalchemy as sa
 from flask_sqlalchemy import SQLAlchemy as SAExtension
-from future.utils import string_types
+from six import string_types, text_type
+from sqlalchemy.event import listens_for
 from sqlalchemy.ext.mutable import Mutable
 
 from .logging import patch_logger
 
 logger = logging.getLogger(__name__)
 
-FLASK_SA_VERSION = pkg_resources.get_distribution('Flask-SQLAlchemy').version
 
-
-@sa.event.listens_for(sa.pool.Pool, "checkout")
+@listens_for(sa.pool.Pool, "checkout")
 def ping_connection(dbapi_connection, connection_record, connection_proxy):
     """Ensure connections are valid.
 
@@ -49,7 +45,7 @@ def ping_connection(dbapi_connection, connection_record, connection_proxy):
     cursor.close()
 
 
-class AbilianBaseSAExtension(SAExtension):
+class SQLAlchemy(SAExtension):
     """Base subclass of :class:`flask_sqlalchemy.SQLAlchemy`.
 
     Add our custom driver hacks.
@@ -70,46 +66,6 @@ class AbilianBaseSAExtension(SAExtension):
             options.setdefault('client_encoding', 'utf8')
 
 
-if StrictVersion(FLASK_SA_VERSION) <= StrictVersion('1.0'):
-    # SA extension's scoped session supports 'bind' parameter only after 1.0. This
-    # is a fix for it. This is required to ensure transaction rollback during
-    # tests, but it's useful in some use cases too.
-    from flask_sqlalchemy import _SignallingSession as BaseSession
-
-    class SignallingSession(BaseSession):
-
-        def __init__(self, db, autocommit=False, autoflush=True, **options):
-            self.app = db.get_app()
-            self._model_changes = {}
-            bind = options.pop('bind', None) or db.engine
-            # actually we are overriding BaseSession.__init__, so we don't want to
-            # call it! Directly call BaseSession parent __init__
-            sa.orm.Session.__init__(self,
-                                    autocommit=autocommit,
-                                    autoflush=autoflush,
-                                    bind=bind,
-                                    binds=db.get_binds(self.app),
-                                    **options)
-
-    class SQLAlchemy(AbilianBaseSAExtension):
-
-        def create_scoped_session(self, options=None):
-            """Helper factory method that creates a scoped session."""
-            # override needed to use our SignallingSession implementation
-            if options is None:
-                options = {}
-            scopefunc = options.pop('scopefunc', None)
-            return sa.orm.scoped_session(
-                partial(SignallingSession, self, **options),
-                scopefunc=scopefunc)
-
-else:
-    # Flask-SQLAlchemy > 1.0: bind parameter is supported
-    SQLAlchemy = AbilianBaseSAExtension
-
-del FLASK_SA_VERSION
-
-
 # PATCH flask_sqlalchemy for proper info in debug toolbar.
 #
 # Original code works only when current app code is involved. If using 3rd party
@@ -156,8 +112,8 @@ def filter_cols(model, *filtered_columns):
     Useful for defer() for example to retain only columns of interest
     """
     m = sa.orm.class_mapper(model)
-    return list(set(p.key for p in m.iterate_properties if hasattr(
-        p, 'columns')).difference(filtered_columns))
+    return list(set(p.key for p in m.iterate_properties
+                    if hasattr(p, 'columns')).difference(filtered_columns))
 
 
 class MutationDict(Mutable, dict):
@@ -413,11 +369,11 @@ class Locale(sa.types.TypeDecorator):
                 return None
             value = babel.Locale.parse(value)
 
-        code = unicode(value.language)
+        code = text_type(value.language)
         if value.territory:
-            code += u'_' + unicode(value.territory)
+            code += u'_' + text_type(value.territory)
         elif value.script:
-            code += u'_' + unicode(value.territory)
+            code += u'_' + text_type(value.territory)
 
         return code
 
