@@ -3,6 +3,8 @@
 from __future__ import (absolute_import, division, print_function,
                         unicode_literals)
 
+from six import text_type
+
 from abilian.core.models.subjects import User
 
 
@@ -14,8 +16,8 @@ def test_non_ascii_password():
 
     user.set_password(u'Hé')
 
-    if not isinstance(user.password, unicode):
+    if not isinstance(user.password, text_type):
         # when actually retrieved from database, it should be unicode
-        user.password = unicode(user.password)
+        user.password = text_type(user.password)
 
     assert user.authenticate(u'Hé')
