@@ -53,9 +53,9 @@ import importlib
 import os
 import re
 import unicodedata
-from contextlib import contextmanager
 from datetime import datetime
 from gettext import GNUTranslations
+from pathlib import Path
 
 import flask_babel
 import pytz
@@ -65,9 +65,9 @@ from babel.localedata import locale_identifiers
 from babel.support import Translations as BaseTranslations
 from flask import _request_ctx_stack, current_app, g, render_template, request
 from flask_babel import Babel as BabelBase
-from flask_babel import force_locale, gettext, lazy_gettext, ngettext
-from future.utils import string_types
-from pathlib import Path
+from flask_babel import (LazyString, force_locale, gettext, lazy_gettext,
+                         ngettext)
+from six import string_types, text_type
 
 __all__ = [
     'babel', 'gettext', '_', 'lazy_gettext', '_l', 'localeselector', 'ngettext',
@@ -111,8 +111,7 @@ def country_name(code):
 
 #: lazy version of :func:`country_name`
 def lazy_country_name(code):
-    from speaklater import make_lazy_string
-    return make_lazy_string(__gettext_territory, code)
+    return LazyString(__gettext_territory, code)
 
 
 def default_country():
@@ -200,13 +199,13 @@ class Babel(BabelBase):
             if not (path.exists() and path.is_dir()):
                 continue
 
-            if not os.access(unicode(path), os.R_OK):
+            if not os.access(text_type(path), os.R_OK):
                 self.app.logger.warning(
                     "Babel translations: read access not allowed {}, skipping."
-                    "".format(repr(unicode((path)).encode('utf-8'))))
+                    "".format(repr(text_type((path)).encode('utf-8'))))
                 continue
 
-            self._translations_paths.append((unicode(path), domain))
+            self._translations_paths.append((text_type(path), domain))
 
 
 class Translations(BaseTranslations):
@@ -384,7 +383,7 @@ _NOT_WORD_RE = re.compile(r'[^\w\s]+', flags=re.UNICODE)
 
 
 def to_lower_ascii(value):
-    value = unicode(value)
+    value = text_type(value)
     value = _NOT_WORD_RE.sub(u' ', value)
     value = unicodedata.normalize('NFKD', value)
     value = value.encode('ascii', 'ignore')
