@@ -21,7 +21,7 @@ try:
 except ImportError:
     CLAMD_AVAILABLE = False
 
-CLAMD_CONF = {'StreamMaxLength': u'25M', 'MaxFileSize': u'25M',}
+CLAMD_CONF = {'StreamMaxLength': u'25M', 'MaxFileSize': u'25M'}
 CLAMD_STREAMMAXLENGTH = 26214400
 CLAMD_MAXFILESIZE = 26214400
 
@@ -30,7 +30,7 @@ if CLAMD_AVAILABLE:
     if conf_path.exists():
         conf_lines = [l.strip() for l in conf_path.open('rt').readlines()]
         CLAMD_CONF = dict(l.split(u' ', 1) for l in conf_lines
-                          if not l.startswith(u'#'))
+                          if not l.startswith('#'))
 
         def _size_to_int(size_str):
             multiplier = 0
@@ -59,7 +59,7 @@ if CLAMD_AVAILABLE:
 
 
 class AntiVirusService(Service):
-    """Antivirus service
+    """Antivirus service.
     """
     name = 'antivirus'
 
