@@ -15,6 +15,7 @@ import pickle
 from datetime import datetime
 
 from flask import current_app
+from six import text_type
 from sqlalchemy.orm import relationship
 from sqlalchemy.schema import Column, ForeignKey
 from sqlalchemy.types import Binary, DateTime, Integer, String, UnicodeText
@@ -108,8 +109,8 @@ class AuditEntry(db.Model):
             repr(self.id), {CREATION: "CREATION",
                             DELETION: "DELETION",
                             UPDATE: "UPDATE"}[self.op],
-            repr(unicode(self.user)), 'related ' if self.related else '',
-            self.entity_type, self.entity_id)
+            repr(text_type(self.user)), 'related '
+            if self.related else '', self.entity_type, self.entity_id)
 
     @property
     def op(self):
@@ -143,8 +144,8 @@ class AuditEntry(db.Model):
         if isinstance(changes, dict):
             changes = Changes.from_legacy(changes)
 
-        for k, v in changes.columns.iteritems():
-            k = unicode(k)
+        for k, v in changes.columns.items():
+            k = text_type(k)
             uv = []
             if isinstance(v, Changes):
                 # field k is a related model with its own changes
@@ -164,9 +165,9 @@ class AuditEntry(db.Model):
                 uv = tuple(uv)
             uchanges.columns[k] = uv
 
-        for attr_name, (appended, removed) in changes.collections.iteritems():
-            appended = sorted(unicode(i) for i in appended)
-            removed = sorted(unicode(i) for i in removed)
+        for attr_name, (appended, removed) in changes.collections.items():
+            appended = sorted(text_type(i) for i in appended)
+            removed = sorted(text_type(i) for i in removed)
             uchanges.collections[attr_name] = (appended, removed)
 
         return uchanges
