@@ -14,6 +14,7 @@ from inspect import isclass
 
 import sqlalchemy as sa
 from flask import current_app, g
+from six import text_type
 from sqlalchemy import event
 from sqlalchemy.orm.attributes import NEVER_SET
 from sqlalchemy.orm.session import Session
@@ -304,7 +305,7 @@ class AuditService(Service):
                 item = model
                 for attr in path:
                     item = getattr(item, attr)
-                enduser_ids.append(unicode(item))
+                enduser_ids.append(text_type(item))
 
             related_name = u'{} {}'.format(meta.backref_attr,
                                            u' '.join(enduser_ids))
@@ -317,14 +318,14 @@ class AuditService(Service):
         return entry
 
     def entries_for(self, entity, limit=None):
-        q = AuditEntry.query \
+        query = AuditEntry.query \
             .filter(AuditEntry.entity == entity) \
             .order_by(AuditEntry.happened_at.desc())
 
         if limit is not None:
-            q = q.limit(limit)
+            query = query.limit(limit)
 
-        return q.all()
+        return query.all()
 
 
 audit_service = AuditService()
