@@ -8,8 +8,11 @@ import datetime
 from itertools import count
 
 import sqlalchemy as sa
+from six import text_type
 from sqlalchemy import (Column, Date, ForeignKey, Integer, Text, Unicode,
                         UnicodeText)
+from sqlalchemy.ext.declarative import declared_attr
+from sqlalchemy.orm import backref, relationship
 from sqlalchemy.orm.attributes import NEVER_SET
 
 from abilian.core.entities import Entity
@@ -25,7 +28,7 @@ class IntegerCollection(db.Model):
     id = Column(Integer, primary_key=True)
 
     def __unicode__(self):
-        return unicode(self.id)
+        return text_type(self.id)
 
 
 class DummyAccount(Entity):
@@ -35,7 +38,7 @@ class DummyAccount(Entity):
     office_phone = Column(UnicodeText, default="")
     birthday = Column(Date)
 
-    @sa.ext.declarative.declared_attr
+    @declared_attr
     def integers(cls):
         secondary_tbl = sa.Table(
             'account_integers',
@@ -53,11 +56,10 @@ class AccountRelated(db.Model):
     id = Column(Integer, primary_key=True)
 
     account_id = Column(Integer, ForeignKey(DummyAccount.id), nullable=False)
-    account = sa.orm.relationship(
-        DummyAccount,
-        backref=sa.orm.backref('data',
-                               order_by='AccountRelated.id',
-                               cascade='all, delete-orphan'))
+    account = relationship(DummyAccount,
+                           backref=backref('data',
+                                           order_by='AccountRelated.id',
+                                           cascade='all, delete-orphan'))
 
     text = Column(UnicodeText, default="")
 
@@ -69,11 +71,10 @@ class CommentRelated(db.Model):
     id = Column(Integer, primary_key=True)
 
     related_id = Column(Integer, ForeignKey(AccountRelated.id), nullable=False)
-    related = sa.orm.relationship(
-        AccountRelated,
-        backref=sa.orm.backref('comments',
-                               order_by='CommentRelated.id',
-                               cascade='all, delete-orphan'))
+    related = relationship(AccountRelated,
+                           backref=backref('comments',
+                                           order_by='CommentRelated.id',
+                                           cascade='all, delete-orphan'))
     text = Column(UnicodeText, default="")
 
 
@@ -113,8 +114,8 @@ class TestAudit(BaseTestCase):
         assert entry.type == UPDATE
         assert entry.entity_id == account.id
         assert entry.entity == account
-        assert entry.changes.columns == {u'website':
-                                         (u'', u'http://www.john.com/')}
+        assert entry.changes.columns == {'website':
+                                         ('', 'http://www.john.com/')}
 
         account.birthday = datetime.date(2012, 12, 25)
         db.session.commit()
@@ -124,20 +125,19 @@ class TestAudit(BaseTestCase):
         assert entry.type == UPDATE
         assert entry.entity_id == account.id
         assert entry.entity == account
-        assert entry.changes.columns == {u'birthday':
+        assert entry.changes.columns == {'birthday':
                                          (None, datetime.date(2012, 12, 25))}
 
         # content hiding
-        account.password = u'new super secret password'
-        assert account.__changes__.columns == {u'password':
-                                               (u'******', u'******')}
+        account.password = 'new super secret password'
+        assert account.__changes__.columns == {'password': ('******', '******')}
         db.session.commit()
 
         entry = AuditEntry.query.order_by(AuditEntry.happened_at).all()[3]
         assert entry.type == UPDATE
         assert entry.entity_id == account.id
         assert entry.entity == account
-        assert entry.changes.columns == {u'password': (u'******', u'******')}
+        assert entry.changes.columns == {'password': ('******', '******')}
 
         # deletion
         db.session.delete(account)
@@ -190,7 +190,7 @@ class TestAudit(BaseTestCase):
         changes = changes['data 1']
         assert changes.columns == {'text': (NEVER_SET, u'text 1'),
                                    'account_id': (NEVER_SET, 1),
-                                   'id': (NEVER_SET, 1),}
+                                   'id': (NEVER_SET, 1)}
 
         comment = CommentRelated(related=data, text='comment')
         db.session.add(comment)
@@ -207,7 +207,7 @@ class TestAudit(BaseTestCase):
         changes = changes['data.comments 1 1']
         assert changes.columns == {'text': (NEVER_SET, u'comment'),
                                    'related_id': (NEVER_SET, 1),
-                                   'id': (NEVER_SET, 1),}
+                                   'id': (NEVER_SET, 1)}
 
         comment = CommentRelated(related=data, text='comment 2')
         db.session.add(comment)
@@ -221,10 +221,11 @@ class TestAudit(BaseTestCase):
         changes = entry.changes.columns
         assert len(changes) == 1
         assert 'data.comments 1 2' in changes
+
         changes = changes['data.comments 1 2']
         assert changes.columns == {'text': (NEVER_SET, u'comment 2'),
                                    'related_id': (NEVER_SET, 1),
-                                   'id': (NEVER_SET, 2),}
+                                   'id': (NEVER_SET, 2)}
 
         # deletion
         db.session.delete(comment)
@@ -251,4 +252,4 @@ class TestAudit(BaseTestCase):
 
         entry = AuditEntry.query.one()
         changes = entry.changes
-        assert changes.collections == {'integers': (['1'], [],)}
+        assert changes.collections == {'integers': (['1'], [])}
