@@ -137,14 +137,15 @@ class AuthService(Service):
         g.user = g.logged_user = user
         is_anonymous = user is None or user.is_anonymous
         security = app.services.get('security')
-        g.is_manager = (user and not is_anonymous and
-                        ((security.has_role(user, 'admin') or
-                          security.has_role(user, 'manager'))))
+        g.is_manager = (user and not is_anonymous and (
+            (security.has_role(user, 'admin') or
+             security.has_role(user, 'manager'))))
 
     def user_logged_out(self, app, user):
-        del g.user
-        del g.logged_user
-        del g.is_manager
+        if hasattr(g, 'user'):
+            del g.user
+            del g.logged_user
+            del g.is_manager
 
     def redirect_to_login(self, next_url=True):
         kw = {}
@@ -155,9 +156,9 @@ class AuthService(Service):
 
     def do_access_control(self):
         """
-    `before_request` handler to check if user should be redirected to login
-    page.
-    """
+        `before_request` handler to check if user should be redirected to login
+        page.
+        """
         if current_app.testing and current_app.config.get("NO_LOGIN"):
             # Special case for tests
             user = User.query.get(0)
