@@ -11,7 +11,6 @@ from __future__ import (absolute_import, division, print_function,
 import random
 import string
 from datetime import datetime
-from urlparse import urljoin, urlparse
 
 from flask import (current_app, flash, redirect, render_template, request,
                    url_for)
@@ -22,6 +21,7 @@ from flask_login import (login_user, logout_user, user_logged_in,
 from flask_mail import Message
 from flask_security.utils import md5
 from itsdangerous import BadSignature, SignatureExpired, URLSafeTimedSerializer
+from six.moves.urllib.parse import urljoin, urlparse
 from sqlalchemy import sql
 from sqlalchemy.orm.exc import NoResultFound
 
@@ -48,7 +48,8 @@ route = login.route
 #
 @route("/login")
 def login_form():
-    """Display the login form."""
+    """Display the login form.
+    """
     next_url = get_redirect_target()
     return render_template("login/login.html", next_url=next_url)
 
@@ -144,8 +145,7 @@ def forgotten_pw_form():
 @route("/forgotten_pw", methods=['POST'])
 @csrf.exempt
 def forgotten_pw(new_user=False):
-    """
-    Reset password for users who have already activated their accounts.
+    """Reset password for users who have already activated their accounts.
     """
     email = request.form.get('email', "").lower()
 
@@ -286,7 +286,7 @@ def generate_reset_password_token(user):
 
 def reset_password_token_status(token):
     """Return the expired status, invalid status, and user of a password reset
-  token.
+    token.
 
     For example::
 
@@ -344,23 +344,24 @@ def send_mail(subject, recipient, template, **context):
 #
 # Logging
 #
+@user_logged_in.connect
 def log_session_start(app, user):
     session = LoginSession.new()
     db.session.add(session)
     db.session.commit()
 
 
+@user_logged_out.connect
 def log_session_end(app, user):
+    if user.is_anonymous:
+        return
+
     session = LoginSession.query.get_active_for(user)
     if session:
         session.ended_at = datetime.utcnow()
         db.session.commit()
 
 
-user_logged_in.connect(log_session_start)
-user_logged_out.connect(log_session_end)
-
-
 # login redirect utilities
 #  from http://flask.pocoo.org/snippets/62/
 def is_safe_url(target):
@@ -379,7 +380,7 @@ def check_for_redirect(target):
         if '.' in endpoint and endpoint.rsplit('.', 1)[0] == 'login':
             # don't redirect to any login view after successful login
             return None
-    except Exception as e:
+    except Exception:
         # exceptions may happen if route is not found for example
         pass
 
