@@ -12,7 +12,6 @@ TODO: rename Converter into ConversionService ?
 from __future__ import (absolute_import, division, print_function,
                         unicode_literals)
 
-import cStringIO as StringIO
 import glob
 import hashlib
 import logging
@@ -26,17 +25,22 @@ import traceback
 from abc import ABCMeta, abstractmethod
 from base64 import decodestring, encodestring
 from contextlib import contextmanager
-from tempfile import mkstemp
-from xmlrpclib import ServerProxy
-
-from future.utils import raise_from, string_types
-from magic import Magic
+from io import BytesIO
 from pathlib import Path
+from tempfile import mkstemp
+
+from magic import Magic
 from PIL import Image
 from PIL.ExifTags import TAGS
+from six import raise_from, string_types, text_type
 
 from abilian.services.image import FIT, resize
 
+try:
+    from xmlrpclib import ServerProxy
+except ImportError:
+    ServerProxy = None
+
 logger = logging.getLogger(__name__)
 
 # For some reason, twill includes a broken version of subprocess.
@@ -66,7 +70,8 @@ class Cache(object):
     CACHE_DIR = None
 
     def _path(self, key):
-        """ file path for `key`"""
+        """File path for `key`:
+        """
         return self.CACHE_DIR / "{}.blob".format(key)
 
     def __contains__(self, key):
@@ -76,7 +81,7 @@ class Cache(object):
         if key in self:
             value = self._path(key).open('rb').read()
             if key.startswith("txt:"):
-                value = unicode(value, encoding="utf8")
+                value = text_type(value, encoding="utf8")
             return value
         else:
             return None
@@ -149,7 +154,7 @@ class Converter(object):
                               mime_type)
 
     def to_text(self, digest, blob, mime_type):
-        """Converts a file to plain text.
+        """Convert a file to plain text.
 
         Useful for full-text indexing. Returns an unicode string.
         """
@@ -182,14 +187,14 @@ class Converter(object):
                               mime_type)
 
     def has_image(self, digest, mime_type, index, size=500):
-        """ Tell if there is a preview image
+        """Tell if there is a preview image.
         """
         cache_key = "img:%s:%s:%s" % (index, size, digest)
         return mime_type.startswith("image/") or cache_key in self.cache
 
     def get_image(self, digest, blob, mime_type, index, size=500):
-        """ Return an image for the given content, only if it already exists in the
-        image cache
+        """Return an image for the given content, only if it already exists in
+        the image cache.
         """
         # Special case, for now (XXX).
         if mime_type.startswith("image/"):
@@ -199,8 +204,7 @@ class Converter(object):
         return self.cache.get(cache_key)
 
     def to_image(self, digest, blob, mime_type, index, size=500):
-        """
-        Converts a file to a list of images. Returns image at the given index.
+        """Convert a file to a list of images. Returns image at the given index.
         """
         # Special case, for now (XXX).
         if mime_type.startswith("image/"):
@@ -234,11 +238,13 @@ class Converter(object):
                               mime_type)
 
     def get_metadata(self, digest, content, mime_type):
-        """Gets a dictionary representing the metadata embedded in the given content."""
+        """Get a dictionary representing the metadata embedded in the given
+        content.
+        """
 
         # XXX: ad-hoc for now, refactor later
         if mime_type.startswith("image/"):
-            img = Image.open(StringIO.StringIO(content))
+            img = Image.open(BytesIO(content))
             ret = {}
             if not hasattr(img, '_getexif'):
                 return {}
@@ -254,13 +260,19 @@ class Converter(object):
                 content = self.to_pdf(digest, content, mime_type)
 
             with make_temp_file(content) as in_fn:
-                output = subprocess.check_output(['pdfinfo', in_fn])
+                try:
+                    output = subprocess.check_output(['pdfinfo', in_fn])
+                except OSError:
+                    logger.error(
+                        "Conversion failed, probably pdfinfo is not installed")
+                    raise
 
             ret = {}
             for line in output.split(b"\n"):
                 if b":" in line:
                     key, value = line.strip().split(b":", 1)
-                    ret["PDF:" + key] = unicode(value.strip(), errors="replace")
+                    ret["PDF:" + key] = text_type(value.strip(),
+                                                  errors="replace")
 
             return ret
 
@@ -338,10 +350,10 @@ class PdfToTextHandler(Handler):
         if encoding in ("binary", None):
             encoding = "ascii"
         try:
-            converted_unicode = unicode(converted, encoding, errors="ignore")
+            converted_unicode = text_type(converted, encoding, errors="ignore")
         except:
             traceback.print_exc()
-            converted_unicode = unicode(converted, errors="ignore")
+            converted_unicode = text_type(converted, errors="ignore")
 
         return converted_unicode
 
@@ -357,8 +369,9 @@ class AbiwordTextHandler(Handler):
              make_temp_file(suffix='.txt') as out_fn:
             try:
                 os.chdir(str(tmp_dir))
-                subprocess.check_call(['abiword', '--to', os.path.basename(
-                    out_fn), os.path.basename(in_fn)])
+                subprocess.check_call(['abiword', '--to',
+                                       os.path.basename(out_fn),
+                                       os.path.basename(in_fn)])
             except Exception as e:
                 raise_from(ConversionError('abiword failed'), e)
             finally:
@@ -370,10 +383,10 @@ class AbiwordTextHandler(Handler):
         if encoding in ("binary", None):
             encoding = "ascii"
         try:
-            converted_unicode = unicode(converted, encoding, errors="ignore")
+            converted_unicode = text_type(converted, encoding, errors="ignore")
         except:
             traceback.print_exc()
-            converted_unicode = unicode(converted, errors="ignore")
+            converted_unicode = text_type(converted, errors="ignore")
 
         return converted_unicode
 
@@ -390,8 +403,9 @@ class AbiwordPDFHandler(Handler):
              make_temp_file(suffix='.pdf') as out_fn:
             try:
                 os.chdir(bytes(self.TMP_DIR))
-                subprocess.check_call(['abiword', '--to', os.path.basename(
-                    out_fn), os.path.basename(in_fn)])
+                subprocess.check_call(['abiword', '--to',
+                                       os.path.basename(out_fn),
+                                       os.path.basename(in_fn)])
             except Exception as e:
                 raise_from(ConversionError('abiword failed'), e)
             finally:
@@ -409,7 +423,7 @@ class ImageMagickHandler(Handler):
         with make_temp_file(blob) as in_fn, make_temp_file() as out_fn:
             try:
                 subprocess.check_call(['convert', in_fn, "pdf:" + out_fn])
-                converted = open(out_fn).read()
+                converted = open(out_fn, 'rb').read()
                 return converted
             except Exception as e:
                 raise_from(ConversionError('convert failed'), e)
@@ -430,7 +444,9 @@ class PdfToPpmHandler(Handler):
 
                 converted_images = []
                 for fn in l:
-                    converted = resize(open(fn).read(), size, size, mode=FIT)
+                    converted = resize(
+                        open(fn, 'rb').read(),
+                        size, size, mode=FIT)
                     converted_images.append(converted)
 
                 return converted_images
@@ -451,12 +467,12 @@ class UnoconvPdfHandler(Handler):
     """
 
     # TODO: add more if needed.
-    accepts_mime_types = ['application/vnd.oasis.*', 'application/msword',
-                          'application/mspowerpoint',
-                          'application/vnd.ms-powerpoint',
-                          'application/vnd.ms-excel', 'application/ms-excel',
-                          'application/vnd.openxmlformats-officedocument.*',
-                          'text/rtf']
+    accepts_mime_types = [
+        'application/vnd.oasis.*', 'application/msword',
+        'application/mspowerpoint', 'application/vnd.ms-powerpoint',
+        'application/vnd.ms-excel', 'application/ms-excel',
+        'application/vnd.openxmlformats-officedocument.*', 'text/rtf'
+    ]
     produces_mime_types = ['application/pdf']
     run_timeout = 60
     _process = None
@@ -499,8 +515,7 @@ class UnoconvPdfHandler(Handler):
         return out
 
     def convert(self, blob, **kw):
-        """
-        Unoconv converter called.
+        """Convert using unoconv converter.
         """
         timeout = self.run_timeout
         with make_temp_file(blob) as in_fn, \
@@ -615,11 +630,12 @@ class WvwareTextHandler(Handler):
             if encoding in ("binary", None):
                 encoding = "ascii"
             try:
-                converted_unicode = unicode(
-                    converted, encoding, errors="ignore")
+                converted_unicode = text_type(converted,
+                                              encoding,
+                                              errors="ignore")
             except:
                 traceback.print_exc()
-                converted_unicode = unicode(converted, errors="ignore")
+                converted_unicode = text_type(converted, errors="ignore")
 
             return converted_unicode
 
