@@ -6,10 +6,10 @@ from __future__ import (absolute_import, division, print_function,
                         unicode_literals)
 
 import hashlib
-from cStringIO import StringIO
+from io import BytesIO
 
-from future.utils import string_types
 from PIL import Image
+from six import string_types
 
 __all__ = ['resize', 'RESIZE_MODES', 'SCALE', 'FIT', 'CROP']
 
@@ -34,7 +34,7 @@ cache = {}
 
 def open_image(img):
     if isinstance(img, string_types):
-        img = StringIO(img)
+        img = BytesIO(img)
 
     pos = img.tell()
     image = Image.open(img)
@@ -59,8 +59,8 @@ def get_save_format(fmt):
 
 
 def resize(orig, width, height, mode=FIT):
-    if isinstance(orig, string_types):
-        orig = StringIO(orig)
+    if isinstance(orig, bytes):
+        orig = BytesIO(orig)
 
     digest = hashlib.md5(orig.read()).digest()
     cache_key = (digest, mode, width, height)
@@ -89,7 +89,7 @@ def resize(orig, width, height, mode=FIT):
         image = _crop_and_resize(image, width, height)
         assert image.size == (width, height)
 
-    output = StringIO()
+    output = BytesIO()
     image.save(output, get_save_format(format))
     converted = output.getvalue()
     cache[cache_key] = converted
