@@ -11,7 +11,7 @@ from operator import attrgetter
 
 import sqlalchemy as sa
 from flask import current_app
-from future.utils import string_types
+from six import string_types
 from whoosh.fields import TEXT
 
 from abilian.core.extensions import db
@@ -39,15 +39,14 @@ class SchemaAdapter(object):
 
     @staticmethod
     def can_adapt(obj_cls):
-        """
-        Returns True if this class can adapt objects of class `obj_cls`
+        """Return True if this class can adapt objects of class `obj_cls`.
         """
         raise NotImplementedError
 
     @abstractmethod
     def retrieve(self, pk, **data):
-        """
-        Returns an object instance given its identifier and optional data kwargs.
+        """Returns an object instance given its identifier and optional data
+        kwargs.
 
         :returns:None if not object instance can be returned
         """
@@ -144,7 +143,7 @@ class SAAdapter(SchemaAdapter):
                 setup_field(name, field_name)
 
         # add missing fields to schema
-        for field_name, field_def in field_definitions.iteritems():
+        for field_name, field_def in field_definitions.items():
             if field_name in schema:
                 continue
 
@@ -172,10 +171,10 @@ class SAAdapter(SchemaAdapter):
         cached = {}
         missed = set()  # negative cache. Might be used especially with dotted names
 
-        for field, attrs in self.doc_attrs.iteritems():
+        for field, attrs in self.doc_attrs.items():
             values = []
 
-            for a, getter in attrs.iteritems():
+            for a, getter in attrs.items():
                 if a in missed:
                     continue
 
