@@ -13,7 +13,8 @@ from abilian.core.sqlalchemy import JSON
 
 
 class UserPreference(db.Model):
-    """An atom of user preference."""
+    """An atom of user preference.
+    """
     __tablename__ = 'user_preference'
     __table_args__ = (UniqueConstraint('user_id', 'key'),)
 
