@@ -65,18 +65,18 @@ class PreferenceService(Service):
                 self.register_panel(panel)
 
     def get_preferences(self, user=None):
-        """Returns a string->value dictionnary representing the given user
-    preferences.
+        """Return a string->value dictionnary representing the given user
+        preferences.
 
-    If no user is provided, the current user is used instead.
-    """
+        If no user is provided, the current user is used instead.
+        """
         if user is None:
             user = current_user
         return {pref.key: pref.value for pref in user.preferences}
 
     def set_preferences(self, user=None, **kwargs):
-        """Sets preferences from keyword arguments.
-    """
+        """Set preferences from keyword arguments.
+        """
         if user is None:
             user = current_user
 
@@ -89,8 +89,8 @@ class PreferenceService(Service):
                 db.session.add(d[k])
 
     def clear_preferences(self, user=None):
-        """Clears the user preferences.
-    """
+        """Clear the user preferences.
+        """
         if user is None:
             user = current_user
 
@@ -115,9 +115,10 @@ class PreferenceService(Service):
             state.blueprint.add_url_rule(rule, endpoint, panel.get)
         if hasattr(panel, 'post'):
             endpoint += "_post"
-            state.blueprint.add_url_rule(
-                rule, endpoint, panel.post,
-                methods=['POST'])
+            state.blueprint.add_url_rule(rule,
+                                         endpoint,
+                                         panel.post,
+                                         methods=['POST'])
 
         state.breadcrumb_items[abs_endpoint] = BreadcrumbItem(
             label=panel.label,
@@ -160,7 +161,8 @@ class PreferenceService(Service):
 
         @bp.route("/")
         def index():
-            """Index redirects to the first accessible panel."""
+            """Index redirects to the first accessible panel.
+            """
 
             # Work around unit test failure. FIXME.
             if current_user.is_anonymous:
