@@ -6,13 +6,13 @@ from __future__ import (absolute_import, division, print_function,
 
 import shutil
 import weakref
+from pathlib import Path
 from uuid import UUID, uuid1
 
 import sqlalchemy as sa
 from flask import _app_ctx_stack, current_app
 from flask.globals import _lookup_app_object
-from future.utils import string_types
-from pathlib import Path
+from six import string_types, text_type
 from sqlalchemy.orm.session import Session
 
 from abilian.services import Service, ServiceState
@@ -27,7 +27,7 @@ def _assert_uuid(uuid):
 
 class RepositoryServiceState(ServiceState):
     #: :class:`Path` path to application repository
-    path = None
+    path = None  # type: Path
 
 
 class RepositoryService(Service):
@@ -49,9 +49,8 @@ class RepositoryService(Service):
 
     # data management: paths and accessors
     def rel_path(self, uuid):
-        """
-        Contruct relative path from repository top directory to the file named
-        after this uuid.
+        """Contruct relative path from repository top directory to the file
+        named after this uuid.
 
         :param:uuid: :class:`UUID` instance
         """
@@ -60,8 +59,7 @@ class RepositoryService(Service):
         return Path(filename[0:2], filename[2:4], filename)
 
     def abs_path(self, uuid):
-        """
-        Return absolute :class:`Path` object for given uuid.
+        """Return absolute :class:`Path` object for given uuid.
 
         :param:uuid: :class:`UUID` instance
         """
@@ -84,8 +82,7 @@ class RepositoryService(Service):
         return path
 
     def set(self, uuid, content, encoding='utf-8'):
-        """
-        Store binary content with uuid as key
+        """Store binary content with uuid as key
 
         :param:uuid: :class:`UUID` instance
         :param:content: string, bytes, or any object with a `read()` method
@@ -96,18 +93,17 @@ class RepositoryService(Service):
             dest.parent.mkdir(0o775, parents=True)
 
         mode = 'tw'
-        if not isinstance(content, unicode):
+        if not isinstance(content, text_type):
             mode = 'bw'
             encoding = None
 
         with dest.open(mode, encoding=encoding) as f:
-            if not isinstance(content, string_types):
+            if not isinstance(content, bytes):
                 content = content.read()
             f.write(content)
 
     def delete(self, uuid):
-        """
-        Delete file with given uuid.
+        """Delete file with given uuid.
 
         :param:uuid: :class:`UUID` instance
         :raises:KeyError if file does not exists
@@ -137,7 +133,7 @@ _REPOSITORY_TRANSACTION = 'abilian_repository_transactions'
 
 
 class SessionRepositoryState(ServiceState):
-    path = None
+    path = None  # type: Path
 
     @property
     def transactions(self):
@@ -460,7 +456,7 @@ class RepositoryTransaction(object):
         self._add_to(uuid, self._set, self._deleted)
 
         mode = 'tw'
-        if not isinstance(content, unicode):
+        if not isinstance(content, text_type):
             mode = 'bw'
             encoding = None
 
