@@ -7,6 +7,7 @@ from __future__ import (absolute_import, division, print_function,
 from datetime import datetime
 from functools import total_ordering
 
+from six import text_type
 from sqlalchemy import sql
 from sqlalchemy.orm import backref, relationship
 from sqlalchemy.schema import (CheckConstraint, Column, ForeignKey, Index,
@@ -36,21 +37,20 @@ class Permission(UniqueName):
     def __init__(self, name, label=None, assignable=True):
         UniqueName.__init__(self, name)
         if label is None:
-            label = u'permission_' + unicode(name)
-        if isinstance(label, unicode):
+            label = u'permission_' + text_type(name)
+        if isinstance(label, text_type):
             label = _l(label)
         self.label = label
 
     def __unicode__(self):
-        return unicode(self.label)
+        return text_type(self.label)
 
     def __lt__(self, other):
-        return unicode(self).__lt__(unicode(other))
+        return text_type(self).__lt__(text_type(other))
 
 
 class PermissionType(UniqueNameType):
-    """
-    Store :class:`Permission`
+    """Store :class:`Permission`
 
     Usage::
     RoleType()
@@ -60,8 +60,7 @@ class PermissionType(UniqueNameType):
 
 @total_ordering
 class Role(UniqueName):
-    """
-    Defines role by name. Roles instances are unique by name.
+    """Defines role by name. Roles instances are unique by name.
 
     :param assignable: this role is can be assigned through security service.
     Non-assignable roles are roles automatically given depending on context (ex:
@@ -72,17 +71,17 @@ class Role(UniqueName):
     def __init__(self, name, label=None, assignable=True):
         UniqueName.__init__(self, name)
         if label is None:
-            label = u'role_' + unicode(name)
-        if isinstance(label, unicode):
+            label = u'role_' + text_type(name)
+        if isinstance(label, text_type):
             label = _l(label)
         self.label = label
         self.assignable = assignable
 
     def __unicode__(self):
-        return unicode(self.label)
+        return text_type(self.label)
 
     def __lt__(self, other):
-        return unicode(self).__lt__(unicode(other))
+        return text_type(self).__lt__(text_type(other))
 
     @classmethod
     def assignable_roles(cls):
@@ -105,14 +104,14 @@ Anonymous = Role('anonymous', _l(u'role_anonymous'), assignable=False)
 
 #: marker for role assigned to 'Authenticated'
 Authenticated = Role('authenticated',
-                     _l(u'role_authenticated'),
+                     _l('role_authenticated'),
                      assignable=False)
 
 #: marker for `admin` role
-Admin = Role('admin', _l(u'role_administrator'))
+Admin = Role('admin', _l('role_administrator'))
 
 #: marker for `manager` role
-Manager = Role('manager', _l(u'role_manager'), assignable=False)
+Manager = Role('manager', _l('role_manager'), assignable=False)
 
 Creator = Role('creator', assignable=False)
 Owner = Role('owner', assignable=False)
@@ -120,16 +119,17 @@ Reader = Role('reader', assignable=False)
 Writer = Role('writer', assignable=False)
 
 # Permissions
-READ = Permission(u'read')
-WRITE = Permission(u'write')
-MANAGE = Permission(u'manage')
-CREATE = Permission(u'create')
-DELETE = Permission(u'delete')
+READ = Permission('read')
+WRITE = Permission('write')
+MANAGE = Permission('manage')
+CREATE = Permission('create')
+DELETE = Permission('delete')
 
 
 class RoleAssignment(db.Model):
     __tablename__ = "roleassignment"
     __table_args__ = (
+        #
         CheckConstraint("(CAST(anonymous AS INTEGER) = 1)"
                         " OR "
                         "((CAST(anonymous AS INTEGER) = 0)"
@@ -138,12 +138,13 @@ class RoleAssignment(db.Model):
                         "  OR "
                         "  (user_id IS NULL AND group_id IS NOT NULL)))",
                         name="roleassignment_ck_user_xor_group"),
+        #
         UniqueConstraint('anonymous',
                          'user_id',
                          'group_id',
                          'role',
                          'object_id',
-                         name='assignment_mapped_role_unique'),)
+                         name='assignment_mapped_role_unique'))
 
     id = Column(Integer, primary_key=True, autoincrement=True, nullable=False)
     role = Column(RoleType, index=True, nullable=False)
@@ -208,7 +209,7 @@ def _postgres_indexes():
             role,
             unique=True,
             postgresql_where=((anonymous == True) & (user_id == None) &
-                              (group_id == None) & (obj == None)),),
+                              (group_id == None) & (obj == None))),
         Index(
             name('user_role_object'),
             user_id,
@@ -303,7 +304,7 @@ def _postgres_indexes():
             PA.permission,
             PA.role,
             unique=True,
-            postgresql_where=(PA.object_id == None),),
+            postgresql_where=(PA.object_id == None))
     ]
 
     for idx in indexes:
