@@ -11,9 +11,10 @@ from itertools import chain
 import sqlalchemy as sa
 from flask import current_app, g
 from flask_login import current_user
-from future.utils import string_types
+from six import string_types, text_type
 from sqlalchemy import sql
 from sqlalchemy.orm import object_session, subqueryload
+from typing import Dict, Set
 
 from abilian.core.entities import Entity
 from abilian.core.extensions import db
@@ -21,13 +22,10 @@ from abilian.core.models.subjects import Group, User
 from abilian.core.util import noproxy
 from abilian.services import Service, ServiceState
 from abilian.services.security.models import Anonymous as AnonymousRole
-from abilian.services.security.models import (CREATE, DELETE, MANAGE,
-                                              PERMISSIONS_ATTR, READ, WRITE,
-                                              Admin, Authenticated, Creator,
-                                              InheritSecurity, Manager, Owner,
-                                              Permission, PermissionAssignment,
-                                              Reader, Role, RoleAssignment,
-                                              SecurityAudit, Writer)
+from abilian.services.security.models import (
+    CREATE, DELETE, MANAGE, PERMISSIONS_ATTR, READ, WRITE, Admin, Authenticated,
+    Creator, InheritSecurity, Manager, Owner, Permission, PermissionAssignment,
+    Reader, Role, RoleAssignment, SecurityAudit, Writer)
 
 #: list of legacy supported permissions when not using :class:`Permission`
 #: instance
@@ -39,11 +37,11 @@ __all__ = ['security', 'SecurityError', 'SecurityService', 'InheritSecurity',
 #: default security matrix
 DEFAULT_PERMISSION_ROLE = dict()
 prm = DEFAULT_PERMISSION_ROLE
-prm[MANAGE] = frozenset((Admin, Manager,))
-prm[WRITE] = frozenset((Admin, Manager, Writer,))
-prm[CREATE] = frozenset((Admin, Manager, Writer,))
-prm[DELETE] = frozenset((Admin, Manager, Writer,))
-prm[READ] = frozenset((Admin, Manager, Writer, Reader,))
+prm[MANAGE] = frozenset((Admin, Manager))
+prm[WRITE] = frozenset((Admin, Manager, Writer))
+prm[CREATE] = frozenset((Admin, Manager, Writer))
+prm[DELETE] = frozenset((Admin, Manager, Writer))
+prm[READ] = frozenset((Admin, Manager, Writer, Reader))
 del prm
 
 
@@ -79,8 +77,7 @@ def require_flush(fun):
 
 
 def query_pa_no_flush(session, permission, role, obj):
-    """
-    query for a :class:`PermissionAssignment` using `session` without any
+    """Query for a :class:`PermissionAssignment` using `session` without any
     `flush()`.
 
     It works by looking in session `new`, `dirty` and `deleted`, and issuing a
@@ -135,7 +132,7 @@ class SecurityService(Service):
         state.use_cache = True
 
     def _needs_flush(self):
-        """ Mark next security queries needs DB flush to have up to date information
+        """Mark next security queries needs DB flush to have up to date information
         """
         self.app_state.needs_db_flush = True
 
@@ -143,8 +140,7 @@ class SecurityService(Service):
         pass
 
     def _current_user_manager(self, session=None):
-        """
-        Returns the current user, or SYSTEM user.
+        """Return the current user, or SYSTEM user.
         """
         if session is None:
             session = db.session()
@@ -182,8 +178,8 @@ class SecurityService(Service):
         session.add(obj)
 
         manager = self._current_user_manager(session=session)
-        op = (SecurityAudit.SET_INHERIT if inherit_security else
-              SecurityAudit.UNSET_INHERIT)
+        op = (SecurityAudit.SET_INHERIT
+              if inherit_security else SecurityAudit.UNSET_INHERIT)
         audit = SecurityAudit(manager=manager,
                               op=op,
                               object=obj,
@@ -198,8 +194,7 @@ class SecurityService(Service):
     #
     @require_flush
     def get_roles(self, principal, object=None, no_group_roles=False):
-        """
-        Gets all the roles attached to given `principal`, on a given `object`.
+        """Get all the roles attached to given `principal`, on a given `object`.
 
         :param principal: a :class:`User` or :class:`Group`
 
@@ -212,7 +207,7 @@ class SecurityService(Service):
         if hasattr(principal, 'is_anonymous') and principal.is_anonymous:
             return [AnonymousRole]
 
-        q = db.session.query(RoleAssignment.role)
+        query = db.session.query(RoleAssignment.role)
         if isinstance(principal, Group):
             filter_principal = RoleAssignment.group == principal
         else:
@@ -222,13 +217,13 @@ class SecurityService(Service):
                 if groups:
                     filter_principal |= RoleAssignment.group_id.in_(groups)
 
-        q = q.filter(filter_principal)
+        query = query.filter(filter_principal)
 
         if object is not None:
             assert isinstance(object, Entity)
 
-        q = q.filter(RoleAssignment.object == object)
-        roles = {i[0] for i in q.all()}
+        query = query.filter(RoleAssignment.object == object)
+        roles = {i[0] for i in query.all()}
 
         if object is not None:
             for attr, role in (('creator', Creator), ('owner', Owner)):
@@ -244,24 +239,23 @@ class SecurityService(Service):
                        groups=True,
                        object=None,
                        as_list=True):
-        """
-        Return all users which are assigned given role
+        """Return all users which are assigned given role.
         """
         if not isinstance(role, Role):
             role = Role(role)
         assert role
         assert (users or groups)
-        q = RoleAssignment.query.filter_by(role=role)
+        query = RoleAssignment.query.filter_by(role=role)
 
         if not anonymous:
-            q = q.filter(RoleAssignment.anonymous == False)
+            query = query.filter(RoleAssignment.anonymous == False)
         if not users:
-            q = q.filter(RoleAssignment.user == None)
+            query = query.filter(RoleAssignment.user == None)
         elif not groups:
-            q = q.filter(RoleAssignment.group == None)
+            query = query.filter(RoleAssignment.group == None)
 
-        q = q.filter(RoleAssignment.object == object)
-        principals = {(ra.user or ra.group) for ra in q.all()}
+        query = query.filter(RoleAssignment.object == object)
+        principals = {(ra.user or ra.group) for ra in query.all()}
 
         if object is not None and role in (Creator, Owner):
             p = object.creator if role == Creator else object.owner
@@ -275,7 +269,7 @@ class SecurityService(Service):
 
     @require_flush
     def _all_roles(self, principal):
-        q = db.session \
+        query = db.session \
             .query(RoleAssignment.object_id, RoleAssignment.role) \
             .outerjoin(Entity) \
             .add_columns(Entity._entity_type)
@@ -286,11 +280,11 @@ class SecurityService(Service):
                 group_ids = (g.id for g in principal.groups)
                 filter_cond |= (RoleAssignment.group_id.in_(group_ids))
 
-            q = q.filter(filter_cond)
+            query = query.filter(filter_cond)
         else:
-            q = q.filter(RoleAssignment.group == principal)
+            query = query.filter(RoleAssignment.group == principal)
 
-        results = q.all()
+        results = query.all()
         all_roles = {}
         for object_id, role, object_type in results:
             if object_id is None:
@@ -315,8 +309,8 @@ class SecurityService(Service):
         principal.__roles_cache__ = cache
 
     def _fill_role_cache(self, principal, overwrite=False):
-        """ Fill role cache for `principal` (User or Group), in order to avoid too
-        many queries when checking role access with 'has_role'
+        """Fill role cache for `principal` (User or Group), in order to avoid
+        too many queries when checking role access with 'has_role'.
 
         Return role_cache of `principal`
         """
@@ -329,13 +323,13 @@ class SecurityService(Service):
 
     @require_flush
     def _fill_role_cache_batch(self, principals, overwrite=False):
-        """ Fill role cache for `principals` (Users and/or Groups), in order to
-        avoid too many queries when checking role access with 'has_role'
+        """Fill role cache for `principals` (Users and/or Groups), in order to
+        avoid too many queries when checking role access with 'has_role'.
         """
         if not self.app_state.use_cache:
             return
 
-        q = db.session.query(RoleAssignment)
+        query = db.session.query(RoleAssignment)
         users = set((u for u in principals if isinstance(u, User)))
         groups = set((g for g in principals if isinstance(g, Group)))
         groups |= set((g for u in users for g in u.groups))
@@ -355,16 +349,16 @@ class SecurityService(Service):
 
         filter_cond = []
         if users:
-            filter_cond.append(RoleAssignment.user_id.in_((u.id for u in users
-                                                          )))
+            filter_cond.append(RoleAssignment.user_id.in_((u.id
+                                                           for u in users)))
         if groups:
-            filter_cond.append(RoleAssignment.group_id.in_((g.id for g in groups
-                                                           )))
+            filter_cond.append(RoleAssignment.group_id.in_((g.id
+                                                            for g in groups)))
 
-        q = q.filter(sql.or_(*filter_cond))
+        query = query.filter(sql.or_(*filter_cond))
         ra_users = {}
         ra_groups = {}
-        for ra in q.all():
+        for ra in query.all():
             if ra.user:
                 all_roles = ra_users.setdefault(ra.user, {})
             else:
@@ -374,13 +368,13 @@ class SecurityService(Service):
                           if ra.object is not None else None)
             all_roles.setdefault(object_key, set()).add(ra.role)
 
-        for group, all_roles in ra_groups.iteritems():
+        for group, all_roles in ra_groups.items():
             self._set_role_cache(group, all_roles)
 
-        for user, all_roles in ra_users.iteritems():
+        for user, all_roles in ra_users.items():
             for gr in user.groups:
                 group_roles = self._fill_role_cache(gr)
-                for object_key, roles in group_roles.iteritems():
+                for object_key, roles in group_roles.items():
                     obj_roles = all_roles.setdefault(object_key, set())
                     obj_roles |= roles
 
@@ -396,9 +390,8 @@ class SecurityService(Service):
                     del u.__roles_cache__
 
     def has_role(self, principal, role, object=None):
-        """
-        True if `principal` has `role` (either globally, if `object` is None, or on
-        the specific `object`).
+        """True if `principal` has `role` (either globally, if `object`
+        is None, or on the specific `object`).
 
         :param:role:  can be a list or tuple of strings or a :class:`Role` instance
 
@@ -441,7 +434,8 @@ class SecurityService(Service):
 
         if object:
             assert isinstance(object, Entity)
-            object_key = u"{}:{}".format(object.object_type, unicode(object.id))
+            object_key = u"{}:{}".format(object.object_type,
+                                         text_type(object.id))
             if Creator in role:
                 if object.creator == principal:
                     return True
@@ -460,8 +454,7 @@ class SecurityService(Service):
         return len(valid_roles & roles) > 0
 
     def grant_role(self, principal, role, obj=None):
-        """
-        Grants `role` to `user` (either globally, if `obj` is None, or on
+        """Grant `role` to `user` (either globally, if `obj` is None, or on
         the specific `obj`).
         """
         assert principal
@@ -482,8 +475,8 @@ class SecurityService(Service):
         else:
             args['group'] = principal
 
-        q = session.query(RoleAssignment)
-        if q.filter_by(**args).limit(1).count():
+        query = session.query(RoleAssignment)
+        if query.filter_by(**args).limit(1).count():
             # role already granted, nothing to do
             return
 
@@ -515,9 +508,8 @@ class SecurityService(Service):
             del principal.__roles_cache__
 
     def ungrant_role(self, principal, role, object=None):
-        """
-        Ungrants `role` to `user` (either globally, if `object` is None, or on
-        the specific `object`).
+        """Ungrant `role` to `user` (either globally, if `object` is None,
+        or on the specific `object`).
         """
         assert principal
         principal = noproxy(principal)
@@ -529,24 +521,25 @@ class SecurityService(Service):
                     anonymous=False,
                     user=None,
                     group=None)
-        q = session.query(RoleAssignment)
-        q = q.filter(RoleAssignment.role == role,
-                     RoleAssignment.object == object)
+        query = session.query(RoleAssignment)
+        query = query.filter(RoleAssignment.role == role,
+                             RoleAssignment.object == object)
 
         if (principal is AnonymousRole or
             (hasattr(principal, 'is_anonymous') and principal.is_anonymous)):
             args['anonymous'] = True
-            q.filter(RoleAssignment.anonymous == False,
-                     RoleAssignment.user == None, RoleAssignment.group == None)
+            query.filter(RoleAssignment.anonymous == False,
+                         RoleAssignment.user == None,
+                         RoleAssignment.group == None)
 
         elif isinstance(principal, User):
             args['user'] = principal
-            q = q.filter(RoleAssignment.user == principal)
+            query = query.filter(RoleAssignment.user == principal)
         else:
             args['group'] = principal
-            q = q.filter(RoleAssignment.group == principal)
+            query = query.filter(RoleAssignment.group == principal)
 
-        ra = q.one()
+        ra = query.one()
         session.delete(ra)
         audit = SecurityAudit(manager=manager, op=SecurityAudit.REVOKE, **args)
         session.add(audit)
@@ -554,19 +547,18 @@ class SecurityService(Service):
         self._clear_role_cache(principal)
 
     @require_flush
-    def get_role_assignements(self, object):
-        session = object_session(object) if object is not None else db.session
+    def get_role_assignements(self, obj):
+        session = object_session(obj) if obj is not None else db.session
         if not session:
             session = db.session()
-        q = session.query(RoleAssignment)
-        q = q.filter(RoleAssignment.object == object) \
+        query = session.query(RoleAssignment)
+        query = query.filter(RoleAssignment.object == obj) \
             .options(subqueryload('user.groups'))
 
-        role_assignments = q.all()
+        role_assignments = query.all()
 
         results = []
         for ra in role_assignments:
-            principal = None
             if ra.anonymous:
                 principal = AnonymousRole
             elif ra.user:
@@ -630,7 +622,7 @@ class SecurityService(Service):
         #FIXME: obj.__class__ could define default permisssion matrix too
 
         if roles is not None:
-            if isinstance(roles, (Role, bytes, unicode)):
+            if isinstance(roles, (Role,) + string_types):
                 roles = (roles,)
 
             for r in roles:
