@@ -8,6 +8,7 @@ import json
 from datetime import timedelta
 
 import sqlalchemy as sa
+from six import text_type
 
 from abilian.core.extensions import db
 
@@ -63,8 +64,8 @@ class Setting(db.Model):
     transformers = _transformers
     key = sa.Column('key', sa.String(length=1000), primary_key=True)
 
-    # type: string (unicode), int, bool, json... or even a long dotted name
-    # if that's what you need. Type must be set before setting `value`
+    #: Can be a string (unicode), int, bool, json... or even a long dotted name
+    #: if that's what you need. Type must be set before setting `value`
     _type = sa.Column('type', sa.String(length=1000), nullable=False)
 
     @property
@@ -95,7 +96,12 @@ class Setting(db.Model):
 
 
 register = _transformers.register
-register('int', bytes, int)
+
+
+def from_int(i):
+    return "{}".format(i).encode()
+
+register('int', from_int, int)
 
 
 def from_bool(b):
@@ -110,7 +116,7 @@ register('bool', from_bool, to_bool)
 
 
 def from_unicode(s):
-    return unicode(s).encode('utf-8')
+    return text_type(s).encode('utf-8')
 
 
 def to_unicode(s):
