@@ -4,7 +4,9 @@ Elements to build test cases for an :class:`abilian.app.Application`
 """
 from __future__ import absolute_import, print_function, division
 
-from future.utils import string_types
+import getpass
+
+from six import string_types
 
 import os
 from time import time
@@ -145,7 +147,8 @@ class BaseTestCase(TestCase):
         for p in (tmp_dir / 'tmp', tmp_dir / 'cache', tmp_dir / 'data'):
             p.mkdir()
 
-        sa_warn = 'error' if cls.SQLALCHEMY_WARNINGS_AS_ERROR else 'default'
+        # sa_warn = 'error' if cls.SQLALCHEMY_WARNINGS_AS_ERROR else 'default'
+        sa_warn = 'default'  # FIXME
         warnings.simplefilter(sa_warn, SAWarning)
 
     @classmethod
@@ -195,7 +198,7 @@ class BaseTestCase(TestCase):
         if self.db.engine.name == 'postgresql':
             # ensure we are on a clean DB: let's use our own schema
             self.__pg_schema = 'test_{}'.format(str(time()).replace('.', '_'))
-            username = self.db.engine.url.username
+            username = self.db.engine.url.username or getpass.getuser()
             with self.db.engine.connect() as conn:
                 with conn.begin():
                     conn.execute('DROP SCHEMA IF EXISTS {} CASCADE'.format(
@@ -226,7 +229,7 @@ class BaseTestCase(TestCase):
 
         with self.db.engine.connect() as conn:
             if self.db.engine.name == 'postgresql':
-                username = self.db.engine.url.username
+                username = self.db.engine.url.username or getpass.getuser()
                 with self.db.engine.connect() as conn:
                     with conn.begin():
                         conn.execute(
