@@ -9,8 +9,8 @@ import re
 
 from flask import current_app, g
 from flask.signals import appcontext_pushed
-from future.utils import string_types
 from jinja2 import Markup, Template
+from six import string_types, text_type
 
 from abilian.core.singleton import UniqueName
 from abilian.web import csrf
@@ -186,11 +186,13 @@ class StaticIcon(DynamicIcon):
                  height=12,
                  css='',
                  size=None):
-        DynamicIcon.__init__(
-            self, endpoint,
-            width, height,
-            css, size,
-            filename=filename)
+        DynamicIcon.__init__(self,
+                             endpoint,
+                             width,
+                             height,
+                             css,
+                             size,
+                             filename=filename)
 
 
 class Endpoint(object):
@@ -211,7 +213,7 @@ class Endpoint(object):
         return self.kwargs.copy()
 
     def __unicode__(self):
-        return unicode(url_for(self.name, *self.args, **self.get_kwargs()))
+        return text_type(url_for(self.name, *self.args, **self.get_kwargs()))
 
     def __repr__(self):
         return '{cls}({name!r}, *{args!r}, **{kwargs!r})'.format(
@@ -380,8 +382,7 @@ class Action(object):
         self._endpoint = endpoint
 
     def available(self, context):
-        """
-        Determine if this actions is available in this `context`.
+        """Determine if this actions is available in this `context`.
 
         :param context: a dict whose content is left to application needs; if
                         :attr:`.condition` is a callable it receives `context`
@@ -440,7 +441,7 @@ class Action(object):
 
         endpoint = self.endpoint
         if endpoint:
-            return unicode(endpoint)
+            return text_type(endpoint)
         return self._url
 
 
@@ -499,22 +500,22 @@ class ActionDropDown(ActionGroup):
     """Renders as a button dropdown
     """
     template_string = u'''
-  <div class="btn-group">
-    <button type="button" class="{{ action.css_class }} dropdown-toggle"
-            data-toggle="dropdown" aria-expanded="false">
-    {%- if action.icon %}{{ action.icon }} {% endif %}
-    {{ action.title }}
-    <span class="caret"></span>
-    </button>
-    <ul class="dropdown-menu" role="menu">
-    {%- for entry in action_items %}
-      {%- if entry.divider %}<li class="divider"></li>{%- endif %}
-      <li>{{ entry.render() }}</a>
-      </li>
-    {%- endfor %}
-    </ul>
-  </div>
-  '''
+    <div class="btn-group">
+        <button type="button" class="{{ action.css_class }} dropdown-toggle"
+                data-toggle="dropdown" aria-expanded="false">
+        {%- if action.icon %}{{ action.icon }} {% endif %}
+        {{ action.title }}
+        <span class="caret"></span>
+        </button>
+        <ul class="dropdown-menu" role="menu">
+        {%- for entry in action_items %}
+            {%- if entry.divider %}<li class="divider"></li>{%- endif %}
+            <li>{{ entry.render() }}</a>
+            </li>
+        {%- endfor %}
+        </ul>
+    </div>
+    '''
 
 
 class ActionGroupItem(Action):
@@ -604,7 +605,7 @@ class ActionRegistry(object):
         if context is None:
             context = self.context
 
-        return filter(lambda a: a.available(context), actions)
+        return [a for a in actions if a.available(context)]
 
     @property
     def _state(self):
