@@ -42,13 +42,13 @@ class SessionLifeTimeKey(Key):
     template = 'admin/settings_session_lifetime.html'
 
     def __init__(self):
-        Key.__init__(
-            self,
-            'PERMANENT_SESSION_LIFETIME',
-            'timedelta',
-            label=_l(u'Session lifetime'),
-            description=_l(u'Session expiration time after last visit. '
-                           u'When session is expired user must login again.'))
+        Key.__init__(self,
+                     'PERMANENT_SESSION_LIFETIME',
+                     'timedelta',
+                     label=_l(u'Session lifetime'),
+                     description=_l(
+                         u'Session expiration time after last visit. '
+                         u'When session is expired user must login again.'))
 
     def value_from_request(self):
         form = request.form
@@ -108,7 +108,8 @@ class SettingsPanel(AdminPanel):
         return current_app.services.get('settings').namespace('config')
 
     def get(self):
-        return render_template('admin/settings.html', keys=self._keys,)
+        return render_template('admin/settings.html',
+                               keys=self._keys,)
 
     @csrf.protect
     def post(self):
