@@ -42,7 +42,7 @@ BabelTranslation = _BabelTranslation()
 
 
 class FormPermissions(object):
-    """Form role/permission manager
+    """Form role/permission manager.
     """
 
     def __init__(self,
@@ -118,10 +118,11 @@ class FormPermissions(object):
                     self.fields.setdefault(field_name,
                                            dict())[permission] = allowed_roles
 
-    def has_permission(
-            self, permission,
-            field=None,
-            obj=None, user=current_user):
+    def has_permission(self,
+                       permission,
+                       field=None,
+                       obj=None,
+                       user=current_user):
         if obj is not None and not isinstance(obj, Entity):
             # permission/role can be set only on entities
             return True
@@ -129,9 +130,9 @@ class FormPermissions(object):
         allowed_roles = (self.default[permission] if permission in self.default
                          else self.default['default'])
         definition = None
-        eval_roles = lambda fun: fun(permission=permission,
-                                     field=field,
-                                     obj=obj)
+
+        def eval_roles(fun):
+            return fun(permission=permission, field=field, obj=obj)
 
         if field is None:
             definition = self.form
@@ -152,13 +153,13 @@ class FormPermissions(object):
             if callable(r):
                 r = eval_roles(r)
 
-            if isinstance(r, (Role, bytes, unicode)):
+            if isinstance(r, (Role,) + string_types):
                 roles.append(r)
             else:
                 roles.extend(r)
 
         svc = current_app.services['security']
-        return svc.has_role(user, role=roles, object=obj,)
+        return svc.has_role(user, role=roles, object=obj)
 
 
 class FormContext(object):
@@ -166,7 +167,7 @@ class FormContext(object):
     Allows :class:`forms <Form>` to set a context during instanciation, so that
     subforms used in formfields / listformfields / etc can perform proper field
     filtering according to original permission and user passed to top form
-    __init__ method.
+    `__init__` method.
     """
     permission = None
     user = None
@@ -312,13 +313,12 @@ if not _PATCHED:
 
     def _core_field_repr(self):
         """
-        __repr__ that shows the name of the field instance. Useful for tracing field
-        errors (like in sentry)
+        `__repr__` that shows the name of the field instance. Useful for tracing field
+        errors (like in Sentry).
         """
         return '<{}.{} at 0x{:x} name={!r}>'.format(self.__class__.__module__,
                                                     self.__class__.__name__,
-                                                    id(self),
-                                                    self.name,)
+                                                    id(self), self.name)
 
     patch_logger.info(Field.__module__ + '.Field.__repr__')
     Field.__repr__ = _core_field_repr
