@@ -16,7 +16,7 @@ from flask.helpers import locked_cached_property
 from flask_babel import format_date, format_datetime, get_locale, get_timezone
 from flask_login import current_user
 from flask_wtf.file import FileField as BaseFileField
-from future.utils import string_types
+from six import string_types
 from wtforms import FieldList as BaseFieldList
 from wtforms import FormField as BaseFormField
 from wtforms import (Field, SelectField, SelectFieldBase, SelectMultipleField,
@@ -113,8 +113,9 @@ class ModelFieldList(FilterFieldListMixin, BaseModelFieldList):
         # instanciation so as to have permission filtering
         field_names = []
         labels = []
-        fieldsubform = self.unbound_field.bind(
-            form=None, name='dummy', _meta=self.meta)
+        fieldsubform = self.unbound_field.bind(form=None,
+                                               name='dummy',
+                                               _meta=self.meta)
         subform = fieldsubform.form_class(csrf_enabled=False)
         for f in subform:
             if f.is_hidden:
@@ -398,6 +399,8 @@ class DateField(Field):
             except ValueError:
                 self.data = None
                 raise ValueError(self.gettext('Not a valid datetime value'))
+        else:
+            self.data = None
 
 
 class Select2Field(SelectField):
@@ -553,9 +556,8 @@ class QuerySelect2Field(SelectFieldBase):
 
     def iter_choices(self):
         if not self.flags.required:
-            yield (None,
-                   None,
-                   self.data == [] if self.multiple else self.data is None,)
+            yield (None, None, self.data == []
+                   if self.multiple else self.data is None)
 
         predicate = (operator.contains if
                      (self.multiple and self.data is not None) else operator.eq)
@@ -662,7 +664,7 @@ class JsonSelect2Field(SelectFieldBase):
 
     def iter_choices(self):
         if not self.flags.required:
-            yield (None, None, self.data is None,)
+            yield (None, None, self.data is None)
 
         data = self.data
         if not self.multiple:
@@ -756,7 +758,7 @@ class LocaleSelectField(SelectField):
 
     def iter_choices(self):
         if not self.flags.required:
-            yield (None, None, self.data is None,)
+            yield (None, None, self.data is None)
 
         for locale, label in i18n.supported_app_locales():
             yield (locale.language, label.capitalize(), locale == self.data)
@@ -772,7 +774,7 @@ class TimezoneField(SelectField):
 
     def iter_choices(self):
         if not self.flags.required:
-            yield (None, None, self.data is None,)
+            yield (None, None, self.data is None)
 
         for tz, label in i18n.timezones_choices():
             yield (tz.zone, label, tz == self.data)
