@@ -11,10 +11,8 @@ import base64
 import cgi
 import logging
 import re
-import urlparse
 from collections import namedtuple
 from datetime import datetime
-from itertools import ifilter
 
 import bleach
 import sqlalchemy as sa
@@ -24,7 +22,9 @@ from flask import (Markup, current_app, g, json, render_template,
 from flask_babel import format_date, format_datetime, format_number, get_locale
 from flask_login import current_user
 from flask_wtf.file import FileField
-from future.utils import string_types
+from six import string_types, text_type
+from six.moves import filter
+from six.moves.urllib import parse
 from wtforms.widgets import PasswordInput as BasePasswordInput
 from wtforms.widgets import TextArea as BaseTextArea
 from wtforms.widgets import HTMLString, Input, Select, html_params
@@ -42,14 +42,14 @@ from .util import babel2datetime
 
 logger = logging.getLogger(__name__)
 
-__all__ = ['linkify_url', 'text2html', 'Column', 'BaseTableView',
-           'MainTableView', 'RelatedTableView', 'AjaxMainTableView',
-           'SingleView', 'Panel', 'Row', 'Chosen', 'TagInput', 'DateInput',
-           'DefaultViewWidget', 'BooleanWidget', 'FloatWidget',
-           'DateTimeWidget', 'DateWidget', 'MoneyWidget', 'EmailWidget',
-           'URLWidget', 'ListWidget', 'TabularFieldListWidget',
-           'ModelListWidget', 'Select2', 'Select2Ajax', 'RichTextWidget',
-           'FileInput', 'EntityWidget']
+__all__ = [
+    'linkify_url', 'text2html', 'Column', 'BaseTableView', 'MainTableView',
+    'RelatedTableView', 'AjaxMainTableView', 'SingleView', 'Panel', 'Row',
+    'Chosen', 'TagInput', 'DateInput', 'DefaultViewWidget', 'BooleanWidget',
+    'FloatWidget', 'DateTimeWidget', 'DateWidget', 'MoneyWidget', 'EmailWidget',
+    'URLWidget', 'ListWidget', 'TabularFieldListWidget', 'ModelListWidget',
+    'Select2', 'Select2Ajax', 'RichTextWidget', 'FileInput', 'EntityWidget'
+]
 
 
 def linkify_url(value):
@@ -67,7 +67,7 @@ def linkify_url(value):
     if not url.startswith("http://") and not url.startswith("https://"):
         url = "http://" + url
 
-    url = urlparse.urlsplit(url).geturl()
+    url = parse.urlsplit(url).geturl()
     if '"' in url:
         url = url.split('"')[0]
     if '<' in url:
@@ -107,7 +107,6 @@ class Column(object):
 
 # TODO: rewrite
 class BaseTableView(object):
-
     show_controls = False
     show_search = None
     paginate = False
@@ -218,7 +217,7 @@ class BaseTableView(object):
             elif column_name in (make_link_on, 'name') \
                     or col.get('linkable'):
                 cell = Markup('<a href="%s">%s</a>' %
-                              (build_url(entity), cgi.escape(unicode(value))))
+                              (build_url(entity), cgi.escape(text_type(value))))
             elif isinstance(value, Entity):
                 cell = Markup('<a href="%s">%s</a>' %
                               (build_url(value), cgi.escape(value.name)))
@@ -234,7 +233,7 @@ class BaseTableView(object):
                     if value is None:
                         value = u''
                     else:
-                        value = unicode(value)
+                        value = text_type(value)
                 cell = value
 
             line.append(cell)
@@ -340,7 +339,7 @@ class AjaxMainTableView(object):
             if not c.has_form_filter:
                 continue
             d = dict(name=c.name,
-                     label=unicode(c.label),
+                     label=text_type(c.label),
                      type=c.form_filter_type,
                      args=c.form_filter_args,
                      unset=c.form_unset_value,)
@@ -394,9 +393,9 @@ class AjaxMainTableView(object):
                 cell = Markup(linkify_url(value))
             elif col.get('linkable'):
                 cell = Markup('<a href="%s">%s</a>' %
-                              (url_for(entity), cgi.escape(unicode(value))))
+                              (url_for(entity), cgi.escape(text_type(value))))
             else:
-                cell = unicode(value)
+                cell = text_type(value)
 
             line.append(cell)
         return line
@@ -447,7 +446,7 @@ class SingleView(object):
                 data[name] = (label, value)
 
             if data:
-                panels.append((panel, data,))
+                panels.append((panel, data))
 
         template = filter(bool, (self.options.get('view_template'),
                                  'widgets/render_single.html'))
@@ -555,7 +554,6 @@ class Row(object):
 
 
 class ModelWidget(object):
-
     edit_template = 'widgets/model_widget_edit.html'
     view_template = 'widgets/model_widget_view.html'
 
@@ -566,7 +564,7 @@ class ModelWidget(object):
             self.view_template = view_template
 
     def __call__(self, field, *args, **kwargs):
-        return render_template(self.edit_template, form=field,)
+        return render_template(self.edit_template, form=field)
 
     def render_view(self, field, *args, **kwargs):
         _to_skip = (None, False, 0, 0.0, '', u'-')
@@ -628,16 +626,16 @@ class TextInput(wtforms.widgets.TextInput):
 
         return Markup(render_template_string(
             u'''
-      <div class="input-group input-group-type-{{ widget.typename }}">
-        {%- if widget.pre_icon %}
-          <div class="input-group-addon">{{ widget.pre_icon }}</div>
-        {%- endif %}
-          <input {{ params | safe}}>
-        {%- if widget.post_icon %}
-          <div class="input-group-addon">{{ widget.post_icon }}</div>
-        {%- endif %}
-      </div>
-      ''',
+            <div class="input-group input-group-type-{{ widget.typename }}">
+            {%- if widget.pre_icon %}
+              <div class="input-group-addon">{{ widget.pre_icon }}</div>
+            {%- endif %}
+              <input {{ params | safe}}>
+            {%- if widget.post_icon %}
+              <div class="input-group-addon">{{ widget.post_icon }}</div>
+            {%- endif %}
+            </div>
+            ''',
             widget=self,
             params=self.html_params(name=field.name, **kwargs)))
 
@@ -711,14 +709,14 @@ class FileInput(object):
                 # due to debugtoolbar capturing template parameters
                 del data['file']
 
-        return Markup(render_template(self.template,
-                                      id=field.id,
-                                      field=field,
-                                      widget=self,
-                                      input=input_elem,
-                                      button_label=button_label,
-                                      existing=existing,
-                                      uploaded=uploads,))
+        ctx = dict(id=field.id,
+                   field=field,
+                   widget=self,
+                   input=input_elem,
+                   button_label=button_label,
+                   existing=existing,
+                   uploaded=uploads)
+        return Markup(render_template(self.template, **ctx))
 
     def build_exisiting_files_list(self, field):
         existing = []
@@ -869,8 +867,9 @@ class Chosen(Select):
         options = dict(kwargs, value=value)
         if selected:
             options['selected'] = True
-        return HTMLString(u'<option %s>%s</option>' %
-                          (html_params(**options), cgi.escape(unicode(label))))
+        return HTMLString(
+            u'<option %s>%s</option>' %
+            (html_params(**options), cgi.escape(text_type(label))))
 
 
 class TagInput(Input):
@@ -999,12 +998,12 @@ class TimeInput(Input):
         input_params = {k: Markup(json.dumps(v))
                         for k, v in input_params.items()}
 
-        return Markup(render_template(self.template,
-                                      id=field_id,
-                                      value=value,
-                                      field=field,
-                                      required=False,
-                                      timepicker_attributes=input_params))
+        ctx = dict(id=field_id,
+                   value=value,
+                   field=field,
+                   required=False,
+                   timepicker_attributes=input_params)
+        return Markup(render_template(self.template, **ctx))
 
 
 class DateTimeInput(object):
@@ -1081,11 +1080,10 @@ class DefaultViewWidget(object):
             return text2html(value)
         else:
             # [], None and other must be rendered using empty string
-            return unicode(value or u'')
+            return text_type(value or u'')
 
 
 class BooleanWidget(wtforms.widgets.CheckboxInput):
-
     # valid data-* options when using boostrap-switch
     _ON_OFF_VALID_OPTIONS = frozenset(
         ('animate', 'indeterminate', 'inverse', 'radio-all-off', 'on-color',
@@ -1096,7 +1094,7 @@ class BooleanWidget(wtforms.widgets.CheckboxInput):
         self.on_off_mode = kwargs.pop('on_off_mode', False)
         self.on_off_options = {}
         on_off_options = kwargs.pop('on_off_options', {})
-        for k, v in on_off_options.iteritems():
+        for k, v in on_off_options.items():
             if k not in self._ON_OFF_VALID_OPTIONS:
                 continue
             self.on_off_options['data-' + k] = v
@@ -1113,12 +1111,12 @@ class BooleanWidget(wtforms.widgets.CheckboxInput):
         return super(BooleanWidget, self).__call__(field, **kwargs)
 
     def render_view(self, field, **kwargs):
-        return u'\u2713' if field.object_data else u''  # Unicode "Check mark"
+        return u'\u2713' if field.object_data else u''  # Text_type "Check mark"
 
 
 class PasswordInput(BasePasswordInput):
     """
-    Supports setting 'autocomplete' at instanciation time
+    Supports setting 'autocomplete' at instanciation time.
     """
 
     def __init__(self, *args, **kwargs):
@@ -1159,8 +1157,8 @@ class DateWidget(wtforms.widgets.TextInput):
 class DateTimeWidget(DateWidget):
 
     def render_view(self, field, **kwargs):
-        return (format_datetime(field.object_data) if field.object_data else
-                u'')
+        return (format_datetime(field.object_data)
+                if field.object_data else u'')
 
 
 class EntityWidget(object):
@@ -1211,7 +1209,7 @@ class MoneyWidget(TextInput):
             val = int(round(val / 1000.0))
 
         # `format_currency()` is not used since it display numbers with cents
-        #units, which we don't want
+        # units, which we don't want
         #
         # \u00A0: non-breakable whitespace
         return u'{value}\u00A0{unit}'.format(value=format_number(val),
@@ -1279,9 +1277,10 @@ class RichTextWidget(object):
     def __call__(self, field, **kwargs):
         value = kwargs.pop('value') if 'value' in kwargs else field._value()
         kwargs.setdefault('allowed_tags', self.allowed_tags)
-        return render_template(
-            self.template, field=field,
-            value=value, kw=kwargs)
+        return render_template(self.template,
+                               field=field,
+                               value=value,
+                               kw=kwargs)
 
 
 class ListWidget(wtforms.widgets.ListWidget):
@@ -1316,10 +1315,10 @@ class ListWidget(wtforms.widgets.ListWidget):
         else:
             data = []
 
-        return Markup(render_template_string('''{%- for obj in data %}
-      <span class="badge">{{ obj }}</span>
-      {%- endfor %}''',
-                                             data=data))
+        tpl = '''{%- for obj in data %}
+              <span class="badge">{{ obj }}</span>
+              {%- endfor %}'''
+        return Markup(render_template_string(tpl, data=data))
 
 
 class FieldListWidget(object):
@@ -1400,7 +1399,7 @@ class ModelListWidget(object):
         rows = []
         for entry in field.entries:
             row = []
-            for f in ifilter(lambda f: not f.is_hidden, entry.form):
+            for f in filter(lambda f: not f.is_hidden, entry.form):
                 row.append(Markup(f.render_view()))
 
             rows.append(Data(*row))
@@ -1447,7 +1446,7 @@ class Select2(Select):
         return Select.__call__(self, field, *args, **kwargs)
 
     def render_view(self, field, **kwargs):
-        labels = [unicode(label) for v, label, checked in field.iter_choices()
+        labels = [text_type(label) for v, label, checked in field.iter_choices()
                   if checked]
         return u'; '.join(labels)
 
@@ -1524,9 +1523,9 @@ class Select2Ajax(object):
         s2_params.update(self.s2_params)
 
         if field.ajax_source:
-            s2_params['ajax'] = {'url': unicode(field.ajax_source)}
+            s2_params['ajax'] = {'url': text_type(field.ajax_source)}
 
-        s2_params['placeholder'] = unicode(field.label.text)
+        s2_params['placeholder'] = text_type(field.label.text)
 
         if not field.flags.required:
             s2_params['allowClear'] = True
@@ -1536,7 +1535,7 @@ class Select2Ajax(object):
             data = [data]
 
         values = self.values_builder(data)
-        input_value = u','.join(unicode(o.id) for o in data if o)
+        input_value = u','.join(text_type(o.id) for o in data if o)
         data_node_id = None
 
         json_data = {}
@@ -1549,12 +1548,12 @@ class Select2Ajax(object):
 
         extra_args = Markup(html_params(**kwargs))
 
-        return Markup(render_template(self.template,
-                                      field=field,
-                                      name=field.name,
-                                      id=field.id,
-                                      input_value=input_value,
-                                      json_data=json_data,
-                                      required=not field.allow_blank,
-                                      data_node_id=data_node_id,
-                                      extra_args=extra_args,))
+        ctx = dict(field=field,
+                   name=field.name,
+                   id=field.id,
+                   input_value=input_value,
+                   json_data=json_data,
+                   required=not field.allow_blank,
+                   data_node_id=data_node_id,
+                   extra_args=extra_args)
+        return Markup(render_template(self.template, **ctx))
