@@ -301,11 +301,11 @@ class ListJson(ModuleView, JSONView):
         end = start + length
 
         total_count = self.module.listing_query.count()
-        q = self.module.list_query(request)
-        count = q.count()
-        q = self.module.ordered_query(request, q)
+        query = self.module.list_query(request)
+        count = query.count()
+        query = self.module.ordered_query(request, query)
 
-        entities = q.slice(start, end).all()
+        entities = query.slice(start, end).all()
         table_view = AjaxMainTableView(
             columns=self.module.list_view_columns,
             name=self.module.managed_class.__name__.lower(),
@@ -561,9 +561,10 @@ class Module(object):
         self.blueprint = Blueprint(self.endpoint, __name__, url_prefix=self.url)
 
         for url, name, methods in self._urls:
-            self.blueprint.add_url_rule(
-                url, name, getattr(self, name),
-                methods=methods)
+            self.blueprint.add_url_rule(url,
+                                        name,
+                                        getattr(self, name),
+                                        methods=methods)
 
         # run default_view decorator
         default_view(self.blueprint,
@@ -614,12 +615,12 @@ class Module(object):
         """
         args = request.args
         search = args.get("sSearch", "").replace("%", "").lower()
-        q = self.read_query.distinct()
+        query = self.read_query.distinct()
 
         for crit in self.search_criterions:
-            q = crit.filter(q, self, request, search)
+            query = crit.filter(query, self, request, search)
 
-        return q
+        return query
 
     def list_query(self, request):
         """
@@ -630,13 +631,13 @@ class Module(object):
         """
         args = request.args
         search = args.get("sSearch", "").replace("%", "").lower()
-        q = self.listing_query
-        q = q.distinct()
+        query = self.listing_query
+        query = query.distinct()
 
         for crit in self.search_criterions:
-            q = crit.filter(q, self, request, search)
+            query = crit.filter(query, self, request, search)
 
-        return q
+        return query
 
     def ordered_query(self, request, query=None):
         """Order query according to request args.
