@@ -5,7 +5,7 @@ from __future__ import (absolute_import, division, print_function,
                         unicode_literals)
 
 import imghdr
-from cStringIO import StringIO
+from io import BytesIO
 
 import babel
 import PIL.Image
@@ -78,8 +78,8 @@ class UserPreferencesForm(Form):
             raise ValidationError(_(u'Could not decode image file'))
 
         # convert to jpeg
-        #FIXME: better do this at model level?
-        jpeg = StringIO()
+        # FIXME: better do this at model level?
+        jpeg = BytesIO()
         im.convert('RGBA').save(jpeg, 'JPEG')
         field.data = jpeg.getvalue()
 
@@ -106,9 +106,10 @@ class UserPreferencesPanel(PreferencePanel):
                      url=url_for('users.photo', user_id=g.user.id)))
             data['photo'] = photo
 
-        form = UserPreferencesForm(
-            obj=g.user, formdata=None,
-            prefix=self.id, **data)
+        form = UserPreferencesForm(obj=g.user,
+                                   formdata=None,
+                                   prefix=self.id,
+                                   **data)
         if form['locale'].data is None:
             form['locale'].data = get_default_locale()
         return render_template('preferences/user.html',
