@@ -5,13 +5,18 @@ from __future__ import (absolute_import, division, print_function,
 
 import logging
 
-from future.utils import string_types
+from six import string_types
 from sqlalchemy import func, orm
 from sqlalchemy.sql.expression import or_
 
 logger = logging.getLogger(__name__)
 
-_UNDEFINED = type(b'UNDEFINED', (object,), {})
+
+class UNDEFINED(object):
+    pass
+
+
+_UNDEFINED = UNDEFINED()
 
 
 class BaseCriterion(object):
@@ -78,8 +83,8 @@ class TextSearchCriterion(BaseCriterion):
 
     def __init__(self, name, label='', attributes=None, search_fmt='%{q}%'):
         super(TextSearchCriterion, self).__init__(name, label)
-        self.attributes = dict.fromkeys(attributes if attributes is not None
-                                        else (name,))
+        self.attributes = dict.fromkeys(attributes
+                                        if attributes is not None else (name,))
         self._attributes_prepared = False
 
         if isinstance(search_fmt, string_types):
