@@ -14,6 +14,7 @@ import redis
 
 from flask import (render_template, request, flash, session, redirect, url_for,
                    current_app, make_response)
+from six import text_type
 
 from abilian.services import get_service
 from abilian.services.security import Admin
@@ -49,11 +50,11 @@ Step = namedtuple('SetupStep', ('name', 'endpoint', 'title', 'description'))
 
 _setup_steps = (
     Step('db', 'step_db', 'Setup Database', 'Setup basic database connection'),
-    Step('redis', 'step_redis', 'Setup Redis', 'Redis connection'), Step(
-        'site_info', 'step_site_info', 'Basic site informations',
-        'Site name, admin email...'), Step(
-            'admin_account', 'step_admin_account', u'Admin account',
-            None), Step('finalize', 'finalize', 'Finalize', None))
+    Step('redis', 'step_redis', 'Setup Redis', 'Redis connection'),
+    Step('site_info', 'step_site_info', 'Basic site informations',
+         'Site name, admin email...'),
+    Step('admin_account', 'step_admin_account', u'Admin account', None),
+    Step('finalize', 'finalize', 'Finalize', None))
 
 
 @setup.before_request
@@ -162,8 +163,8 @@ def step_db_validate():
     db_uri += u'/'
 
     if dialect == u'sqlite' and (not database or database == u':memory:'):
-        database = unicode(Path(current_app.instance_path) / u'data' /
-                           u'sqlite.db')
+        database = text_type(Path(current_app.instance_path) / u'data' /
+                             u'sqlite.db')
 
     db_uri += database
 
