@@ -4,6 +4,7 @@
 from __future__ import absolute_import, print_function, unicode_literals
 
 import sqlalchemy as sa
+from six import text_type
 
 from abilian.core.models.tag import Tag, entity_tag_tbl
 from abilian.i18n import _
@@ -37,9 +38,8 @@ class TagCriterion(BaseCriterion):
         join_clause = entity_tag_tbl.join(
             self.model,
             self.model.id == entity_tag_tbl.c.entity_id,)
-        model_tags = sa.sql.select(
-            [entity_tag_tbl.c.tag_id],
-            from_obj=join_clause)
+        model_tags = sa.sql.select([entity_tag_tbl.c.tag_id],
+                                   from_obj=join_clause)
         return Tag.query.filter(Tag.ns == self.ns,
                                 Tag.id.in_(model_tags))\
                         .all()
@@ -68,10 +68,9 @@ class TagCriterion(BaseCriterion):
         if not tags:
             return query
 
-        cond = sa.sql.exists(sa.sql.select(
-            [1],
-            sa.sql.and_(entity_tag_tbl.c.entity_id == self.model.id,
-                        entity_tag_tbl.c.tag_id.in_(t.id for t in tags)),))
+        cond = sa.sql.exists(sa.sql.select([1], sa.sql.and_(
+            entity_tag_tbl.c.entity_id == self.model.id,
+            entity_tag_tbl.c.tag_id.in_(t.id for t in tags))))
         return query.filter(cond)
 
     @property
@@ -85,4 +84,4 @@ class TagCriterion(BaseCriterion):
     @property
     def form_filter_args(self):
         # expected value: [list of selectable items, is multiple?]
-        return [[(unicode(t.id), t.label) for t in self.valid_tags], True,]
+        return [[(text_type(t.id), t.label) for t in self.valid_tags], True]
