@@ -85,14 +85,14 @@ class TagsField(Field):
             all_tags.add(tag)
 
 
-_NS = StringField(u'Namespace', validators=[required()], filters=(strip,),)
+_NS = StringField(u'Namespace', validators=[required()], filters=[strip])
 
 
 class TagForm(Form):
     """
     Form for a single tag
     """
-    label = StringField(u'Label', filters=(strip,), validators=[required(),])
+    label = StringField(u'Label', filters=[strip], validators=[required()])
 
 
 class TagNSForm(TagForm):
