@@ -10,6 +10,7 @@ import logging
 import sqlalchemy as sa
 from flask import (current_app, flash, g, redirect, render_template, request,
                    url_for)
+from six import text_type
 from werkzeug.exceptions import BadRequest, NotFound
 
 from abilian.core.entities import ValidationError
@@ -179,9 +180,10 @@ CANCEL_BUTTON = ButtonAction(
     btn_class='default cancel'  # .cancel: if jquery.validate is used it will
 )  # properly skip validation
 
-EDIT_BUTTON = ButtonAction(
-    'form', 'edit', btn_class='primary',
-    title=_l(u'Save'))
+EDIT_BUTTON = ButtonAction('form',
+                           'edit',
+                           btn_class='primary',
+                           title=_l(u'Save'))
 
 
 class ObjectEdit(ObjectView):
@@ -220,10 +222,13 @@ class ObjectEdit(ObjectView):
                  message_success=None,
                  *args,
                  **kwargs):
-        ObjectView.__init__(
-            self, Model,
-            pk, Form, template=template,
-            *args, **kwargs)
+        ObjectView.__init__(self,
+                            Model,
+                            pk,
+                            Form,
+                            template=template,
+                            *args,
+                            **kwargs)
         if view_endpoint is not None:
             self.view_endpoint = view_endpoint
 
@@ -270,7 +275,7 @@ class ObjectEdit(ObjectView):
         return redirect(self.view_url())
 
     def message_success(self):
-        return unicode(self._message_success)
+        return text_type(self._message_success)
 
     # actions
     def handle_action(self, action):
@@ -433,9 +438,10 @@ class ObjectEdit(ObjectView):
         return None
 
 
-CREATE_BUTTON = ButtonAction(
-    'form', 'create', btn_class='primary',
-    title=_l(u'Create'))
+CREATE_BUTTON = ButtonAction('form',
+                             'create',
+                             btn_class='primary',
+                             title=_l(u'Create'))
 CHAIN_CREATE_BUTTON = ButtonAction(
     'form',
     'chain_create',
