@@ -4,4 +4,5 @@ assert not 'twill' in subprocess.__file__
 
 from sqlalchemy.exc import SAWarning
 import warnings
-warnings.simplefilter('error', SAWarning)
+
+#warnings.simplefilter('error', SAWarning)
